"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FirstTimeFreePlatform:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FirstTimeFreePlatformEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FirstTimeFreePlatform.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DISABLED: _FirstTimeFreePlatform.ValueType  # 0
    WEB: _FirstTimeFreePlatform.ValueType  # 1
    APP: _FirstTimeFreePlatform.ValueType  # 2

class FirstTimeFreePlatform(_FirstTimeFreePlatform, metaclass=_FirstTimeFreePlatformEnumTypeWrapper): ...

DISABLED: FirstTimeFreePlatform.ValueType  # 0
WEB: FirstTimeFreePlatform.ValueType  # 1
APP: FirstTimeFreePlatform.ValueType  # 2
global___FirstTimeFreePlatform = FirstTimeFreePlatform

class _LabelCodes:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LabelCodesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LabelCodes.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    WJ: _LabelCodes.ValueType  # 0
    SQ: _LabelCodes.ValueType  # 1
    VJ: _LabelCodes.ValueType  # 2
    YJ: _LabelCodes.ValueType  # 3
    J_PLUS: _LabelCodes.ValueType  # 4
    REVIVAL: _LabelCodes.ValueType  # 5
    CREATORS: _LabelCodes.ValueType  # 6
    MEE: _LabelCodes.ValueType  # 7
    TYJ: _LabelCodes.ValueType  # 8
    OTHERS: _LabelCodes.ValueType  # 9
    SKJ: _LabelCodes.ValueType  # 10
    GIGA: _LabelCodes.ValueType  # 11
    UJ: _LabelCodes.ValueType  # 12
    DX: _LabelCodes.ValueType  # 13

class LabelCodes(_LabelCodes, metaclass=_LabelCodesEnumTypeWrapper): ...

WJ: LabelCodes.ValueType  # 0
SQ: LabelCodes.ValueType  # 1
VJ: LabelCodes.ValueType  # 2
YJ: LabelCodes.ValueType  # 3
J_PLUS: LabelCodes.ValueType  # 4
REVIVAL: LabelCodes.ValueType  # 5
CREATORS: LabelCodes.ValueType  # 6
MEE: LabelCodes.ValueType  # 7
TYJ: LabelCodes.ValueType  # 8
OTHERS: LabelCodes.ValueType  # 9
SKJ: LabelCodes.ValueType  # 10
GIGA: LabelCodes.ValueType  # 11
UJ: LabelCodes.ValueType  # 12
DX: LabelCodes.ValueType  # 13
global___LabelCodes = LabelCodes

class _Language:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LanguageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Language.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ENGLISH: _Language.ValueType  # 0
    SPANISH: _Language.ValueType  # 1
    FRENCH: _Language.ValueType  # 2
    INDONESIAN: _Language.ValueType  # 3
    PORTUGUESE_BR: _Language.ValueType  # 4
    RUSSIAN: _Language.ValueType  # 5
    THAI: _Language.ValueType  # 6
    GERMAN: _Language.ValueType  # 7
    ITALIAN: _Language.ValueType  # 8
    VIETNAMESE: _Language.ValueType  # 9

class Language(_Language, metaclass=_LanguageEnumTypeWrapper): ...

ENGLISH: Language.ValueType  # 0
SPANISH: Language.ValueType  # 1
FRENCH: Language.ValueType  # 2
INDONESIAN: Language.ValueType  # 3
PORTUGUESE_BR: Language.ValueType  # 4
RUSSIAN: Language.ValueType  # 5
THAI: Language.ValueType  # 6
GERMAN: Language.ValueType  # 7
ITALIAN: Language.ValueType  # 8
VIETNAMESE: Language.ValueType  # 9
global___Language = Language

class _RankingTabType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RankingTabTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RankingTabType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOTTEST: _RankingTabType.ValueType  # 0
    TRENDING: _RankingTabType.ValueType  # 1
    COMPLETED: _RankingTabType.ValueType  # 2

class RankingTabType(_RankingTabType, metaclass=_RankingTabTypeEnumTypeWrapper): ...

HOTTEST: RankingTabType.ValueType  # 0
TRENDING: RankingTabType.ValueType  # 1
COMPLETED: RankingTabType.ValueType  # 2
global___RankingTabType = RankingTabType

class _TitleUpdateStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TitleUpdateStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TitleUpdateStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NONE: _TitleUpdateStatus.ValueType  # 0
    NEW: _TitleUpdateStatus.ValueType  # 1
    UP: _TitleUpdateStatus.ValueType  # 2
    REEDITION: _TitleUpdateStatus.ValueType  # 3
    CREATORS_STATUS: _TitleUpdateStatus.ValueType  # 4
    OUR_PICKS: _TitleUpdateStatus.ValueType  # 5

class TitleUpdateStatus(_TitleUpdateStatus, metaclass=_TitleUpdateStatusEnumTypeWrapper): ...

NONE: TitleUpdateStatus.ValueType  # 0
NEW: TitleUpdateStatus.ValueType  # 1
UP: TitleUpdateStatus.ValueType  # 2
REEDITION: TitleUpdateStatus.ValueType  # 3
CREATORS_STATUS: TitleUpdateStatus.ValueType  # 4
OUR_PICKS: TitleUpdateStatus.ValueType  # 5
global___TitleUpdateStatus = TitleUpdateStatus

@typing.final
class AdNetworkList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADNETWORKS_FIELD_NUMBER: builtins.int
    @property
    def adNetworks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdNetwork]: ...
    def __init__(
        self,
        *,
        adNetworks: collections.abc.Iterable[global___AdNetwork] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adNetworks", b"adNetworks"]) -> None: ...

global___AdNetworkList = AdNetworkList

@typing.final
class AdRewardNetworkList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADNETWORKS_FIELD_NUMBER: builtins.int
    TOKEN_FIELD_NUMBER: builtins.int
    REWARDVIEWCOUNT_FIELD_NUMBER: builtins.int
    token: builtins.str
    rewardViewCount: builtins.int
    @property
    def adNetworks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdNetwork]: ...
    def __init__(
        self,
        *,
        adNetworks: collections.abc.Iterable[global___AdNetwork] | None = ...,
        token: builtins.str = ...,
        rewardViewCount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adNetworks", b"adNetworks", "rewardViewCount", b"rewardViewCount", "token", b"token"]) -> None: ...

global___AdRewardNetworkList = AdRewardNetworkList

@typing.final
class AdNetwork(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AdType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AdTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdNetwork._AdType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STILL_IMAGE: AdNetwork._AdType.ValueType  # 0
        MOVIE: AdNetwork._AdType.ValueType  # 1
        NATIVE_MANUAL: AdNetwork._AdType.ValueType  # 2
        NATIVE_MEDIUM: AdNetwork._AdType.ValueType  # 3
        MREC: AdNetwork._AdType.ValueType  # 4
        REWARD: AdNetwork._AdType.ValueType  # 5

    class AdType(_AdType, metaclass=_AdTypeEnumTypeWrapper): ...
    STILL_IMAGE: AdNetwork.AdType.ValueType  # 0
    MOVIE: AdNetwork.AdType.ValueType  # 1
    NATIVE_MANUAL: AdNetwork.AdType.ValueType  # 2
    NATIVE_MEDIUM: AdNetwork.AdType.ValueType  # 3
    MREC: AdNetwork.AdType.ValueType  # 4
    REWARD: AdNetwork.AdType.ValueType  # 5

    class _NetworkCase:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _NetworkCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdNetwork._NetworkCase.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NETWORK_NOT_SET: AdNetwork._NetworkCase.ValueType  # 0
        FACEBOOK: AdNetwork._NetworkCase.ValueType  # 1
        ADMOB: AdNetwork._NetworkCase.ValueType  # 2
        MOPUB: AdNetwork._NetworkCase.ValueType  # 3
        ADSENSE: AdNetwork._NetworkCase.ValueType  # 4
        APPLOVIN: AdNetwork._NetworkCase.ValueType  # 5
        APPLOVINMAX: AdNetwork._NetworkCase.ValueType  # 6

    class NetworkCase(_NetworkCase, metaclass=_NetworkCaseEnumTypeWrapper): ...
    NETWORK_NOT_SET: AdNetwork.NetworkCase.ValueType  # 0
    FACEBOOK: AdNetwork.NetworkCase.ValueType  # 1
    ADMOB: AdNetwork.NetworkCase.ValueType  # 2
    MOPUB: AdNetwork.NetworkCase.ValueType  # 3
    ADSENSE: AdNetwork.NetworkCase.ValueType  # 4
    APPLOVIN: AdNetwork.NetworkCase.ValueType  # 5
    APPLOVINMAX: AdNetwork.NetworkCase.ValueType  # 6

    @typing.final
    class Facebook(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        PLACEMENTID_FIELD_NUMBER: builtins.int
        placementID: builtins.str
        def __init__(
            self,
            *,
            placementID: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["placementID", b"placementID"]) -> None: ...

    @typing.final
    class Admob(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UNITID_FIELD_NUMBER: builtins.int
        unitID: builtins.str
        def __init__(
            self,
            *,
            unitID: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["unitID", b"unitID"]) -> None: ...

    @typing.final
    class Adsense(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UNITID_FIELD_NUMBER: builtins.int
        LOCATION_FIELD_NUMBER: builtins.int
        unitID: builtins.str
        location: builtins.str
        def __init__(
            self,
            *,
            unitID: builtins.str = ...,
            location: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["location", b"location", "unitID", b"unitID"]) -> None: ...

    @typing.final
    class Applovin(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UNITID_FIELD_NUMBER: builtins.int
        unitID: builtins.str
        def __init__(
            self,
            *,
            unitID: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["unitID", b"unitID"]) -> None: ...

    @typing.final
    class Mopub(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UNITID_FIELD_NUMBER: builtins.int
        unitID: builtins.str
        def __init__(
            self,
            *,
            unitID: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["unitID", b"unitID"]) -> None: ...

    @typing.final
    class ApplovinMax(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        UNITID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        AMAZONAPPID_FIELD_NUMBER: builtins.int
        AMAZONADUNITID_FIELD_NUMBER: builtins.int
        unitID: builtins.str
        type: builtins.int
        amazonAppId: builtins.str
        amazonAdUnitId: builtins.str
        def __init__(
            self,
            *,
            unitID: builtins.str = ...,
            type: builtins.int = ...,
            amazonAppId: builtins.str = ...,
            amazonAdUnitId: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["amazonAdUnitId", b"amazonAdUnitId", "amazonAppId", b"amazonAppId", "type", b"type", "unitID", b"unitID"]) -> None: ...

    FACEBOOK_FIELD_NUMBER: builtins.int
    ADMOB_FIELD_NUMBER: builtins.int
    MOPUB_FIELD_NUMBER: builtins.int
    ADSENSE_FIELD_NUMBER: builtins.int
    APPLOVIN_FIELD_NUMBER: builtins.int
    APPLOVINMAX_FIELD_NUMBER: builtins.int
    @property
    def facebook(self) -> global___AdNetwork.Facebook: ...
    @property
    def admob(self) -> global___AdNetwork.Admob: ...
    @property
    def mopub(self) -> global___AdNetwork.Mopub: ...
    @property
    def adsense(self) -> global___AdNetwork.Adsense: ...
    @property
    def applovin(self) -> global___AdNetwork.Applovin: ...
    @property
    def applovinMax(self) -> global___AdNetwork.ApplovinMax: ...
    def __init__(
        self,
        *,
        facebook: global___AdNetwork.Facebook | None = ...,
        admob: global___AdNetwork.Admob | None = ...,
        mopub: global___AdNetwork.Mopub | None = ...,
        adsense: global___AdNetwork.Adsense | None = ...,
        applovin: global___AdNetwork.Applovin | None = ...,
        applovinMax: global___AdNetwork.ApplovinMax | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["admob", b"admob", "adsense", b"adsense", "applovin", b"applovin", "applovinMax", b"applovinMax", "facebook", b"facebook", "mopub", b"mopub"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admob", b"admob", "adsense", b"adsense", "applovin", b"applovin", "applovinMax", b"applovinMax", "facebook", b"facebook", "mopub", b"mopub"]) -> None: ...

global___AdNetwork = AdNetwork

@typing.final
class AllFreeTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FREETITLES_FIELD_NUMBER: builtins.int
    @property
    def freeTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FreeTitle]: ...
    def __init__(
        self,
        *,
        freeTitles: collections.abc.Iterable[global___FreeTitle] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["freeTitles", b"freeTitles"]) -> None: ...

global___AllFreeTitlesView = AllFreeTitlesView

@typing.final
class AllTicketTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TICKETTITLE_FIELD_NUMBER: builtins.int
    @property
    def ticketTitle(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TicketTitles]: ...
    def __init__(
        self,
        *,
        ticketTitle: collections.abc.Iterable[global___TicketTitles] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["ticketTitle", b"ticketTitle"]) -> None: ...

global___AllTicketTitlesView = AllTicketTitlesView

@typing.final
class AllTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLES_FIELD_NUMBER: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        titles: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["titles", b"titles"]) -> None: ...

global___AllTitlesView = AllTitlesView

@typing.final
class AllTitlesViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLTITLESGROUP_FIELD_NUMBER: builtins.int
    @property
    def allTitlesGroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AllTitlesGroup]: ...
    def __init__(
        self,
        *,
        allTitlesGroup: collections.abc.Iterable[global___AllTitlesGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allTitlesGroup", b"allTitlesGroup"]) -> None: ...

global___AllTitlesViewV2 = AllTitlesViewV2

@typing.final
class Banner(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGEURL_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ISPR_FIELD_NUMBER: builtins.int
    imageUrl: builtins.str
    id: builtins.int
    width: builtins.int
    height: builtins.int
    isPr: builtins.bool
    @property
    def action(self) -> global___TransitionAction: ...
    def __init__(
        self,
        *,
        imageUrl: builtins.str = ...,
        action: global___TransitionAction | None = ...,
        id: builtins.int = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        isPr: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "height", b"height", "id", b"id", "imageUrl", b"imageUrl", "isPr", b"isPr", "width", b"width"]) -> None: ...

global___Banner = Banner

@typing.final
class Chapter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLEID_FIELD_NUMBER: builtins.int
    CHAPTERID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    THUMBNAILURL_FIELD_NUMBER: builtins.int
    STARTTIMESTAMP_FIELD_NUMBER: builtins.int
    ENDTIMESTAMP_FIELD_NUMBER: builtins.int
    ALREADYVIEWED_FIELD_NUMBER: builtins.int
    ISVERTICALONLY_FIELD_NUMBER: builtins.int
    CHAPTERTICKETENDTIME_FIELD_NUMBER: builtins.int
    VIEWEDFORFREE_FIELD_NUMBER: builtins.int
    ISHORIZONTALONLY_FIELD_NUMBER: builtins.int
    VIEWCOUNT_FIELD_NUMBER: builtins.int
    COMMENTCOUNT_FIELD_NUMBER: builtins.int
    titleId: builtins.int
    chapterId: builtins.int
    name: builtins.str
    subTitle: builtins.str
    thumbnailUrl: builtins.str
    startTimeStamp: builtins.int
    endTimeStamp: builtins.int
    alreadyViewed: builtins.bool
    isVerticalOnly: builtins.bool
    chapterTicketEndtime: builtins.int
    viewedForFree: builtins.bool
    isHorizontalOnly: builtins.bool
    viewCount: builtins.int
    commentCount: builtins.int
    def __init__(
        self,
        *,
        titleId: builtins.int = ...,
        chapterId: builtins.int = ...,
        name: builtins.str = ...,
        subTitle: builtins.str = ...,
        thumbnailUrl: builtins.str = ...,
        startTimeStamp: builtins.int = ...,
        endTimeStamp: builtins.int = ...,
        alreadyViewed: builtins.bool = ...,
        isVerticalOnly: builtins.bool = ...,
        chapterTicketEndtime: builtins.int = ...,
        viewedForFree: builtins.bool = ...,
        isHorizontalOnly: builtins.bool = ...,
        viewCount: builtins.int = ...,
        commentCount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alreadyViewed", b"alreadyViewed", "chapterId", b"chapterId", "chapterTicketEndtime", b"chapterTicketEndtime", "commentCount", b"commentCount", "endTimeStamp", b"endTimeStamp", "isHorizontalOnly", b"isHorizontalOnly", "isVerticalOnly", b"isVerticalOnly", "name", b"name", "startTimeStamp", b"startTimeStamp", "subTitle", b"subTitle", "thumbnailUrl", b"thumbnailUrl", "titleId", b"titleId", "viewCount", b"viewCount", "viewedForFree", b"viewedForFree"]) -> None: ...

global___Chapter = Chapter

@typing.final
class CommentIcon(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IMAGEURL_FIELD_NUMBER: builtins.int
    id: builtins.int
    imageUrl: builtins.str
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        imageUrl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "imageUrl", b"imageUrl"]) -> None: ...

global___CommentIcon = CommentIcon

@typing.final
class CommentListView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TitleDetailComment(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TITLEID_FIELD_NUMBER: builtins.int
        TITLENAME_FIELD_NUMBER: builtins.int
        CHAPTERNAME_FIELD_NUMBER: builtins.int
        CREDIT_FIELD_NUMBER: builtins.int
        titleId: builtins.int
        titleName: builtins.str
        chapterName: builtins.str
        credit: builtins.str
        def __init__(
            self,
            *,
            titleId: builtins.int = ...,
            titleName: builtins.str = ...,
            chapterName: builtins.str = ...,
            credit: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["chapterName", b"chapterName", "credit", b"credit", "titleId", b"titleId", "titleName", b"titleName"]) -> None: ...

    COMMENTS_FIELD_NUMBER: builtins.int
    IFSETUSERNAME_FIELD_NUMBER: builtins.int
    TITLEDETAILCOMMENT_FIELD_NUMBER: builtins.int
    ifSetUserName: builtins.bool
    @property
    def comments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Comment]: ...
    @property
    def titleDetailComment(self) -> global___CommentListView.TitleDetailComment: ...
    def __init__(
        self,
        *,
        comments: collections.abc.Iterable[global___Comment] | None = ...,
        ifSetUserName: builtins.bool = ...,
        titleDetailComment: global___CommentListView.TitleDetailComment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["titleDetailComment", b"titleDetailComment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["comments", b"comments", "ifSetUserName", b"ifSetUserName", "titleDetailComment", b"titleDetailComment"]) -> None: ...

global___CommentListView = CommentListView

@typing.final
class Comment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    ICONURL_FIELD_NUMBER: builtins.int
    ISMYCOMMENT_FIELD_NUMBER: builtins.int
    ALREADYLIKED_FIELD_NUMBER: builtins.int
    NUMBEROFLIKES_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    id: builtins.int
    index: builtins.int
    userName: builtins.str
    iconUrl: builtins.str
    isMyComment: builtins.bool
    alreadyLiked: builtins.bool
    numberOfLikes: builtins.int
    body: builtins.str
    created: builtins.int
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        index: builtins.int = ...,
        userName: builtins.str = ...,
        iconUrl: builtins.str = ...,
        isMyComment: builtins.bool = ...,
        alreadyLiked: builtins.bool = ...,
        numberOfLikes: builtins.int = ...,
        body: builtins.str = ...,
        created: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alreadyLiked", b"alreadyLiked", "body", b"body", "created", b"created", "iconUrl", b"iconUrl", "id", b"id", "index", b"index", "isMyComment", b"isMyComment", "numberOfLikes", b"numberOfLikes", "userName", b"userName"]) -> None: ...

global___Comment = Comment

@typing.final
class FreeViewDialogue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLATFORM_FIELD_NUMBER: builtins.int
    DIALOGUEURL_FIELD_NUMBER: builtins.int
    PUBLISHERBANNER_FIELD_NUMBER: builtins.int
    platform: global___FirstTimeFreePlatform.ValueType
    dialogueUrl: builtins.str
    @property
    def publisherBanner(self) -> global___Banner: ...
    def __init__(
        self,
        *,
        platform: global___FirstTimeFreePlatform.ValueType = ...,
        dialogueUrl: builtins.str = ...,
        publisherBanner: global___Banner | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["publisherBanner", b"publisherBanner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dialogueUrl", b"dialogueUrl", "platform", b"platform", "publisherBanner", b"publisherBanner"]) -> None: ...

global___FreeViewDialogue = FreeViewDialogue

@typing.final
class DownloadableImagesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOADABLEIMAGES_FIELD_NUMBER: builtins.int
    @property
    def downloadableImages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DownloadableImageGroup]: ...
    def __init__(
        self,
        *,
        downloadableImages: collections.abc.Iterable[global___DownloadableImageGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["downloadableImages", b"downloadableImages"]) -> None: ...

global___DownloadableImagesView = DownloadableImagesView

@typing.final
class DownloadableImageGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IMAGEURL_FIELD_NUMBER: builtins.int
    IMAGETITLE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.int
    imageUrl: builtins.str
    imageTitle: builtins.str
    width: builtins.int
    height: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        imageUrl: builtins.str = ...,
        imageTitle: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["height", b"height", "id", b"id", "imageTitle", b"imageTitle", "imageUrl", b"imageUrl", "type", b"type", "width", b"width"]) -> None: ...

global___DownloadableImageGroup = DownloadableImageGroup

@typing.final
class ErrorResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ErrorResult._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DEFAULT: ErrorResult._Action.ValueType  # 0
        UNAUTHORIZED: ErrorResult._Action.ValueType  # 1
        MAINTENANCE: ErrorResult._Action.ValueType  # 2
        GEOIP_BLOCKING: ErrorResult._Action.ValueType  # 3

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    DEFAULT: ErrorResult.Action.ValueType  # 0
    UNAUTHORIZED: ErrorResult.Action.ValueType  # 1
    MAINTENANCE: ErrorResult.Action.ValueType  # 2
    GEOIP_BLOCKING: ErrorResult.Action.ValueType  # 3

    ACTION_FIELD_NUMBER: builtins.int
    ENGLISHPOPUP_FIELD_NUMBER: builtins.int
    SPANISHPOPUP_FIELD_NUMBER: builtins.int
    DEBUGINFO_FIELD_NUMBER: builtins.int
    POPUPS_FIELD_NUMBER: builtins.int
    action: global___ErrorResult.Action.ValueType
    debugInfo: builtins.str
    @property
    def englishPopup(self) -> global___Popup.OSDefault: ...
    @property
    def spanishPopup(self) -> global___Popup.OSDefault: ...
    @property
    def popups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Popup.OSDefault]: ...
    def __init__(
        self,
        *,
        action: global___ErrorResult.Action.ValueType = ...,
        englishPopup: global___Popup.OSDefault | None = ...,
        spanishPopup: global___Popup.OSDefault | None = ...,
        debugInfo: builtins.str = ...,
        popups: collections.abc.Iterable[global___Popup.OSDefault] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["englishPopup", b"englishPopup", "spanishPopup", b"spanishPopup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "debugInfo", b"debugInfo", "englishPopup", b"englishPopup", "popups", b"popups", "spanishPopup", b"spanishPopup"]) -> None: ...

global___ErrorResult = ErrorResult

@typing.final
class FavoriteTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLELANGUAGES_FIELD_NUMBER: builtins.int
    FAVORITETITLES_FIELD_NUMBER: builtins.int
    @property
    def availableLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailableLanguages]: ...
    @property
    def favoriteTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FavoriteTitleGroup]: ...
    def __init__(
        self,
        *,
        availableLanguages: collections.abc.Iterable[global___AvailableLanguages] | None = ...,
        favoriteTitles: collections.abc.Iterable[global___FavoriteTitleGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["availableLanguages", b"availableLanguages", "favoriteTitles", b"favoriteTitles"]) -> None: ...

global___FavoriteTitlesView = FavoriteTitlesView

@typing.final
class FavoriteTitleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    language: global___Language.ValueType
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        language: global___Language.ValueType = ...,
        titles: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language", b"language", "titles", b"titles"]) -> None: ...

global___FavoriteTitleGroup = FavoriteTitleGroup

@typing.final
class FeaturedTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Contents(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _DataCase:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _DataCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeaturedTitlesView.Contents._DataCase.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            DATA_NOT_SET: FeaturedTitlesView.Contents._DataCase.ValueType  # 0
            BANNER: FeaturedTitlesView.Contents._DataCase.ValueType  # 1
            TITLE_LIST: FeaturedTitlesView.Contents._DataCase.ValueType  # 2

        class DataCase(_DataCase, metaclass=_DataCaseEnumTypeWrapper): ...
        DATA_NOT_SET: FeaturedTitlesView.Contents.DataCase.ValueType  # 0
        BANNER: FeaturedTitlesView.Contents.DataCase.ValueType  # 1
        TITLE_LIST: FeaturedTitlesView.Contents.DataCase.ValueType  # 2

        DATA_FIELD_NUMBER: builtins.int
        TITLELIST_FIELD_NUMBER: builtins.int
        data: global___FeaturedTitlesView.Contents.DataCase.ValueType
        @property
        def titleList(self) -> global___TitleList: ...
        def __init__(
            self,
            *,
            data: global___FeaturedTitlesView.Contents.DataCase.ValueType = ...,
            titleList: global___TitleList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["titleList", b"titleList"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["data", b"data", "titleList", b"titleList"]) -> None: ...

    MAINBANNER_FIELD_NUMBER: builtins.int
    SUBBANNER1_FIELD_NUMBER: builtins.int
    SUBBANNER2_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    @property
    def mainBanner(self) -> global___Banner: ...
    @property
    def subBanner1(self) -> global___Banner: ...
    @property
    def subBanner2(self) -> global___Banner: ...
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeaturedTitlesView.Contents]: ...
    def __init__(
        self,
        *,
        mainBanner: global___Banner | None = ...,
        subBanner1: global___Banner | None = ...,
        subBanner2: global___Banner | None = ...,
        contents: collections.abc.Iterable[global___FeaturedTitlesView.Contents] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["mainBanner", b"mainBanner", "subBanner1", b"subBanner1", "subBanner2", b"subBanner2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["contents", b"contents", "mainBanner", b"mainBanner", "subBanner1", b"subBanner1", "subBanner2", b"subBanner2"]) -> None: ...

global___FeaturedTitlesView = FeaturedTitlesView

@typing.final
class FeaturedTitlesViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Contents(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BANNER_FIELD_NUMBER: builtins.int
        TITLELIST_FIELD_NUMBER: builtins.int
        RANKEDTITLES_FIELD_NUMBER: builtins.int
        @property
        def banner(self) -> global___Banner: ...
        @property
        def titleList(self) -> global___TitleList: ...
        @property
        def rankedTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
        def __init__(
            self,
            *,
            banner: global___Banner | None = ...,
            titleList: global___TitleList | None = ...,
            rankedTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["banner", b"banner", "titleList", b"titleList"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["banner", b"banner", "rankedTitles", b"rankedTitles", "titleList", b"titleList"]) -> None: ...

    TOPSEARCHBANNERS_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    @property
    def topSearchBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeaturedTitlesViewV2.Contents]: ...
    def __init__(
        self,
        *,
        topSearchBanners: collections.abc.Iterable[global___Banner] | None = ...,
        contents: collections.abc.Iterable[global___FeaturedTitlesViewV2.Contents] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["contents", b"contents", "topSearchBanners", b"topSearchBanners"]) -> None: ...

global___FeaturedTitlesViewV2 = FeaturedTitlesViewV2

@typing.final
class Feedback(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ResponseType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResponseTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Feedback._ResponseType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        QUESTION: Feedback._ResponseType.ValueType  # 0
        ANSWER: Feedback._ResponseType.ValueType  # 1

    class ResponseType(_ResponseType, metaclass=_ResponseTypeEnumTypeWrapper): ...
    QUESTION: Feedback.ResponseType.ValueType  # 0
    ANSWER: Feedback.ResponseType.ValueType  # 1

    TIMESTAMP_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    RESPONSETYPE_FIELD_NUMBER: builtins.int
    timeStamp: builtins.int
    body: builtins.str
    responseType: global___Feedback.ResponseType.ValueType
    def __init__(
        self,
        *,
        timeStamp: builtins.int = ...,
        body: builtins.str = ...,
        responseType: global___Feedback.ResponseType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "responseType", b"responseType", "timeStamp", b"timeStamp"]) -> None: ...

global___Feedback = Feedback

@typing.final
class FeedbackView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEEDBACKLIST_FIELD_NUMBER: builtins.int
    @property
    def feedbackList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feedback]: ...
    def __init__(
        self,
        *,
        feedbackList: collections.abc.Iterable[global___Feedback] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["feedbackList", b"feedbackList"]) -> None: ...

global___FeedbackView = FeedbackView

@typing.final
class HistoryView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HISTORYBANNERS_FIELD_NUMBER: builtins.int
    VIEWHISTORY_FIELD_NUMBER: builtins.int
    @property
    def historyBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def viewHistory(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        historyBanners: collections.abc.Iterable[global___Banner] | None = ...,
        viewHistory: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["historyBanners", b"historyBanners", "viewHistory", b"viewHistory"]) -> None: ...

global___HistoryView = HistoryView

@typing.final
class HomeViewV3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPBANNERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    POPUP_FIELD_NUMBER: builtins.int
    DISPLAYTRACKINGPOPUP_FIELD_NUMBER: builtins.int
    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    SERVICEANNOUNCEMENTS_FIELD_NUMBER: builtins.int
    displayTrackingPopup: builtins.bool
    @property
    def topBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdatedTitleV2Group]: ...
    @property
    def popup(self) -> global___Popup: ...
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def serviceAnnouncements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAnnouncement]: ...
    def __init__(
        self,
        *,
        topBanners: collections.abc.Iterable[global___Banner] | None = ...,
        groups: collections.abc.Iterable[global___UpdatedTitleV2Group] | None = ...,
        popup: global___Popup | None = ...,
        displayTrackingPopup: builtins.bool = ...,
        userSubscription: global___Subscription | None = ...,
        serviceAnnouncements: collections.abc.Iterable[global___ServiceAnnouncement] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["popup", b"popup", "userSubscription", b"userSubscription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["displayTrackingPopup", b"displayTrackingPopup", "groups", b"groups", "popup", b"popup", "serviceAnnouncements", b"serviceAnnouncements", "topBanners", b"topBanners", "userSubscription", b"userSubscription"]) -> None: ...

global___HomeViewV3 = HomeViewV3

@typing.final
class HomeViewV4(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Sections(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _SectionCase:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SectionCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HomeViewV4.Sections._SectionCase.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SECTION_NOT_SET: HomeViewV4.Sections._SectionCase.ValueType  # 0
            WEEKLY_SECTION: HomeViewV4.Sections._SectionCase.ValueType  # 1
            RANKING_SECTION: HomeViewV4.Sections._SectionCase.ValueType  # 2
            PREVIEW_SECTION: HomeViewV4.Sections._SectionCase.ValueType  # 3
            TITLE_LIST_SECTION: HomeViewV4.Sections._SectionCase.ValueType  # 4
            BANNER_SECTION: HomeViewV4.Sections._SectionCase.ValueType  # 5

        class SectionCase(_SectionCase, metaclass=_SectionCaseEnumTypeWrapper): ...
        SECTION_NOT_SET: HomeViewV4.Sections.SectionCase.ValueType  # 0
        WEEKLY_SECTION: HomeViewV4.Sections.SectionCase.ValueType  # 1
        RANKING_SECTION: HomeViewV4.Sections.SectionCase.ValueType  # 2
        PREVIEW_SECTION: HomeViewV4.Sections.SectionCase.ValueType  # 3
        TITLE_LIST_SECTION: HomeViewV4.Sections.SectionCase.ValueType  # 4
        BANNER_SECTION: HomeViewV4.Sections.SectionCase.ValueType  # 5

        WEEKLYSECTION_FIELD_NUMBER: builtins.int
        RANKINGSECTION_FIELD_NUMBER: builtins.int
        PREVIEWSECTION_FIELD_NUMBER: builtins.int
        TITLELISTSECTION_FIELD_NUMBER: builtins.int
        BANNERSECTION_FIELD_NUMBER: builtins.int
        @property
        def weeklySection(self) -> global___HomeViewV4.WeeklySection: ...
        @property
        def rankingSection(self) -> global___HomeViewV4.RankingSection: ...
        @property
        def previewSection(self) -> global___HomeViewV4.PreviewSection: ...
        @property
        def titleListSection(self) -> global___HomeViewV4.TitleListSection: ...
        @property
        def bannerSection(self) -> global___HomeViewV4.BannerSection: ...
        def __init__(
            self,
            *,
            weeklySection: global___HomeViewV4.WeeklySection | None = ...,
            rankingSection: global___HomeViewV4.RankingSection | None = ...,
            previewSection: global___HomeViewV4.PreviewSection | None = ...,
            titleListSection: global___HomeViewV4.TitleListSection | None = ...,
            bannerSection: global___HomeViewV4.BannerSection | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["bannerSection", b"bannerSection", "previewSection", b"previewSection", "rankingSection", b"rankingSection", "titleListSection", b"titleListSection", "weeklySection", b"weeklySection"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["bannerSection", b"bannerSection", "previewSection", b"previewSection", "rankingSection", b"rankingSection", "titleListSection", b"titleListSection", "weeklySection", b"weeklySection"]) -> None: ...

    @typing.final
    class WeeklySection(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class WeeklyContent(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            ISUPDATED_FIELD_NUMBER: builtins.int
            UPDATEDTIMESTAMP_FIELD_NUMBER: builtins.int
            CONTENTITEMS_FIELD_NUMBER: builtins.int
            isUpdated: builtins.bool
            updatedTimeStamp: builtins.int
            @property
            def contentItems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HomeViewV4.WeeklySection.ContentItem]: ...
            def __init__(
                self,
                *,
                isUpdated: builtins.bool = ...,
                updatedTimeStamp: builtins.int = ...,
                contentItems: collections.abc.Iterable[global___HomeViewV4.WeeklySection.ContentItem] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["contentItems", b"contentItems", "isUpdated", b"isUpdated", "updatedTimeStamp", b"updatedTimeStamp"]) -> None: ...

        @typing.final
        class ContentItem(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _ContentCase:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _ContentCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                CONTENT_NOT_SET: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 0
                PR_BANNER: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 1
                MV_BANNER: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 2
                TITLE_GROUP: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 3
                CAROUSEL_BANNERS: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 4
                MINOR_LANGUAGE_BANNER: HomeViewV4.WeeklySection.ContentItem._ContentCase.ValueType  # 5

            class ContentCase(_ContentCase, metaclass=_ContentCaseEnumTypeWrapper): ...
            CONTENT_NOT_SET: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 0
            PR_BANNER: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 1
            MV_BANNER: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 2
            TITLE_GROUP: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 3
            CAROUSEL_BANNERS: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 4
            MINOR_LANGUAGE_BANNER: HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType  # 5

            CONTENT_FIELD_NUMBER: builtins.int
            MVBANNER_FIELD_NUMBER: builtins.int
            TITLEGROUP_FIELD_NUMBER: builtins.int
            CAROUSELBANNERS_FIELD_NUMBER: builtins.int
            MINORLANGUAGEBANNER_FIELD_NUMBER: builtins.int
            content: global___HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType
            @property
            def mVBanner(self) -> global___HomeViewV4.WeeklySection.MVBanner: ...
            @property
            def titleGroup(self) -> global___HomeViewV4.WeeklySection.TitleGroup: ...
            @property
            def carouselBanners(self) -> global___HomeViewV4.WeeklySection.CarouselBanner: ...
            @property
            def minorLanguageBanner(self) -> global___HomeViewV4.WeeklySection.MinorLanguageBanner: ...
            def __init__(
                self,
                *,
                content: global___HomeViewV4.WeeklySection.ContentItem.ContentCase.ValueType = ...,
                mVBanner: global___HomeViewV4.WeeklySection.MVBanner | None = ...,
                titleGroup: global___HomeViewV4.WeeklySection.TitleGroup | None = ...,
                carouselBanners: global___HomeViewV4.WeeklySection.CarouselBanner | None = ...,
                minorLanguageBanner: global___HomeViewV4.WeeklySection.MinorLanguageBanner | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["carouselBanners", b"carouselBanners", "mVBanner", b"mVBanner", "minorLanguageBanner", b"minorLanguageBanner", "titleGroup", b"titleGroup"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["carouselBanners", b"carouselBanners", "content", b"content", "mVBanner", b"mVBanner", "minorLanguageBanner", b"minorLanguageBanner", "titleGroup", b"titleGroup"]) -> None: ...

        @typing.final
        class MVBanner(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            IMAGEURL_FIELD_NUMBER: builtins.int
            TITLEGROUPS_FIELD_NUMBER: builtins.int
            imageUrl: builtins.str
            @property
            def titleGroups(self) -> global___OriginalTitleGroup: ...
            def __init__(
                self,
                *,
                imageUrl: builtins.str = ...,
                titleGroups: global___OriginalTitleGroup | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["titleGroups", b"titleGroups"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["imageUrl", b"imageUrl", "titleGroups", b"titleGroups"]) -> None: ...

        @typing.final
        class TitleGroup(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TITLEGROUPS_FIELD_NUMBER: builtins.int
            @property
            def titleGroups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OriginalTitleGroup]: ...
            def __init__(
                self,
                *,
                titleGroups: collections.abc.Iterable[global___OriginalTitleGroup] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["titleGroups", b"titleGroups"]) -> None: ...

        @typing.final
        class CarouselBanner(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            BANNERS_FIELD_NUMBER: builtins.int
            @property
            def banners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
            def __init__(
                self,
                *,
                banners: collections.abc.Iterable[global___Banner] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["banners", b"banners"]) -> None: ...

        @typing.final
        class MinorLanguageBanner(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TITLEGROUPS_FIELD_NUMBER: builtins.int
            @property
            def titleGroups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OriginalTitleGroup]: ...
            def __init__(
                self,
                *,
                titleGroups: collections.abc.Iterable[global___OriginalTitleGroup] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["titleGroups", b"titleGroups"]) -> None: ...

        CONTENTS_FIELD_NUMBER: builtins.int
        @property
        def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HomeViewV4.WeeklySection.WeeklyContent]: ...
        def __init__(
            self,
            *,
            contents: collections.abc.Iterable[global___HomeViewV4.WeeklySection.WeeklyContent] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["contents", b"contents"]) -> None: ...

    @typing.final
    class RankingSection(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class RankingTab(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TABTYPE_FIELD_NUMBER: builtins.int
            RANKEDTITLES_FIELD_NUMBER: builtins.int
            tabType: global___RankingTabType.ValueType
            @property
            def rankedTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
            def __init__(
                self,
                *,
                tabType: global___RankingTabType.ValueType = ...,
                rankedTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["rankedTitles", b"rankedTitles", "tabType", b"tabType"]) -> None: ...

        RANKINGTABS_FIELD_NUMBER: builtins.int
        @property
        def rankingTabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HomeViewV4.RankingSection.RankingTab]: ...
        def __init__(
            self,
            *,
            rankingTabs: collections.abc.Iterable[global___HomeViewV4.RankingSection.RankingTab] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["rankingTabs", b"rankingTabs"]) -> None: ...

    @typing.final
    class PreviewSection(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class PreviewTab(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TABTYPE_FIELD_NUMBER: builtins.int
            CHAPTERPAGESLIST_FIELD_NUMBER: builtins.int
            tabType: global___RankingTabType.ValueType
            @property
            def chapterPagesList(self) -> global___ChapterPageList: ...
            def __init__(
                self,
                *,
                tabType: global___RankingTabType.ValueType = ...,
                chapterPagesList: global___ChapterPageList | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["chapterPagesList", b"chapterPagesList"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["chapterPagesList", b"chapterPagesList", "tabType", b"tabType"]) -> None: ...

        PREVIEWTABS_FIELD_NUMBER: builtins.int
        @property
        def previewTabs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HomeViewV4.PreviewSection.PreviewTab]: ...
        def __init__(
            self,
            *,
            previewTabs: collections.abc.Iterable[global___HomeViewV4.PreviewSection.PreviewTab] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["previewTabs", b"previewTabs"]) -> None: ...

    @typing.final
    class TitleListSection(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TITLELIST_FIELD_NUMBER: builtins.int
        @property
        def titleList(self) -> global___TitleList: ...
        def __init__(
            self,
            *,
            titleList: global___TitleList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["titleList", b"titleList"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["titleList", b"titleList"]) -> None: ...

    @typing.final
    class BannerSection(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BANNERS_FIELD_NUMBER: builtins.int
        @property
        def banners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
        def __init__(
            self,
            *,
            banners: collections.abc.Iterable[global___Banner] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["banners", b"banners"]) -> None: ...

    SECTIONS_FIELD_NUMBER: builtins.int
    POPUP_FIELD_NUMBER: builtins.int
    DISPLAYTRACKINGPOPUP_FIELD_NUMBER: builtins.int
    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    SERVICEANNOUNCEMENTS_FIELD_NUMBER: builtins.int
    displayTrackingPopup: builtins.bool
    @property
    def sections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HomeViewV4.Sections]: ...
    @property
    def popup(self) -> global___Popup: ...
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def serviceAnnouncements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAnnouncement]: ...
    def __init__(
        self,
        *,
        sections: collections.abc.Iterable[global___HomeViewV4.Sections] | None = ...,
        popup: global___Popup | None = ...,
        displayTrackingPopup: builtins.bool = ...,
        userSubscription: global___Subscription | None = ...,
        serviceAnnouncements: collections.abc.Iterable[global___ServiceAnnouncement] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["popup", b"popup", "userSubscription", b"userSubscription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["displayTrackingPopup", b"displayTrackingPopup", "popup", b"popup", "sections", b"sections", "serviceAnnouncements", b"serviceAnnouncements", "userSubscription", b"userSubscription"]) -> None: ...

global___HomeViewV4 = HomeViewV4

@typing.final
class InitialViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GDPRAGREEMENTREQUIRED_FIELD_NUMBER: builtins.int
    AVAILABLELANGUAGES_FIELD_NUMBER: builtins.int
    gdprAgreementRequired: builtins.bool
    @property
    def availableLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailableLanguages]: ...
    def __init__(
        self,
        *,
        gdprAgreementRequired: builtins.bool = ...,
        availableLanguages: collections.abc.Iterable[global___AvailableLanguages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["availableLanguages", b"availableLanguages", "gdprAgreementRequired", b"gdprAgreementRequired"]) -> None: ...

global___InitialViewV2 = InitialViewV2

@typing.final
class IntroduceSubscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    TITLECOUNTTEXT_FIELD_NUMBER: builtins.int
    CHAPTERCOUNTTEXT_FIELD_NUMBER: builtins.int
    subscription: builtins.str
    titleCountText: builtins.str
    chapterCountText: builtins.str
    def __init__(
        self,
        *,
        subscription: builtins.str = ...,
        titleCountText: builtins.str = ...,
        chapterCountText: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chapterCountText", b"chapterCountText", "subscription", b"subscription", "titleCountText", b"titleCountText"]) -> None: ...

global___IntroduceSubscription = IntroduceSubscription

@typing.final
class LabeledView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    LABELEDTITLESGROUP_FIELD_NUMBER: builtins.int
    @property
    def label(self) -> global___Label: ...
    @property
    def labeledTitlesGroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LabeledTitlesGroup]: ...
    def __init__(
        self,
        *,
        label: global___Label | None = ...,
        labeledTitlesGroup: collections.abc.Iterable[global___LabeledTitlesGroup] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["label", b"label", "labeledTitlesGroup", b"labeledTitlesGroup"]) -> None: ...

global___LabeledView = LabeledView

@typing.final
class Label(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    label: global___LabelCodes.ValueType
    description: builtins.str
    def __init__(
        self,
        *,
        label: global___LabelCodes.ValueType = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "label", b"label"]) -> None: ...

global___Label = Label

@typing.final
class Languages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULTUILANGUAGE_FIELD_NUMBER: builtins.int
    DEFAULTCONTENTLANGUAGEONE_FIELD_NUMBER: builtins.int
    DEFAULTCONTENTLANGUAGETWO_FIELD_NUMBER: builtins.int
    DEFAULTCONTENTLANGUAGETHREE_FIELD_NUMBER: builtins.int
    AVAILABLELANGUAGES_FIELD_NUMBER: builtins.int
    defaultUiLanguage: global___Language.ValueType
    defaultContentLanguageOne: global___Language.ValueType
    defaultContentLanguageTwo: global___Language.ValueType
    defaultContentLanguageThree: global___Language.ValueType
    @property
    def availableLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailableLanguages]: ...
    def __init__(
        self,
        *,
        defaultUiLanguage: global___Language.ValueType = ...,
        defaultContentLanguageOne: global___Language.ValueType = ...,
        defaultContentLanguageTwo: global___Language.ValueType = ...,
        defaultContentLanguageThree: global___Language.ValueType = ...,
        availableLanguages: collections.abc.Iterable[global___AvailableLanguages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["availableLanguages", b"availableLanguages", "defaultContentLanguageOne", b"defaultContentLanguageOne", "defaultContentLanguageThree", b"defaultContentLanguageThree", "defaultContentLanguageTwo", b"defaultContentLanguageTwo", "defaultUiLanguage", b"defaultUiLanguage"]) -> None: ...

global___Languages = Languages

@typing.final
class AvailableLanguages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_FIELD_NUMBER: builtins.int
    TITLESCOUNT_FIELD_NUMBER: builtins.int
    language: global___Language.ValueType
    titlesCount: builtins.int
    def __init__(
        self,
        *,
        language: global___Language.ValueType = ...,
        titlesCount: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language", b"language", "titlesCount", b"titlesCount"]) -> None: ...

global___AvailableLanguages = AvailableLanguages

@typing.final
class MangaViewer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class TitleAvailableLanguages(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TITLEID_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        ISNEW_FIELD_NUMBER: builtins.int
        titleId: builtins.int
        language: global___Language.ValueType
        isNew: builtins.bool
        def __init__(
            self,
            *,
            titleId: builtins.int = ...,
            language: global___Language.ValueType = ...,
            isNew: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["isNew", b"isNew", "language", b"language", "titleId", b"titleId"]) -> None: ...

    PAGES_FIELD_NUMBER: builtins.int
    CHAPTERID_FIELD_NUMBER: builtins.int
    CHAPTERS_FIELD_NUMBER: builtins.int
    SNS_FIELD_NUMBER: builtins.int
    TITLENAME_FIELD_NUMBER: builtins.int
    CHAPTERNAME_FIELD_NUMBER: builtins.int
    NUMBEROFCOMMENTS_FIELD_NUMBER: builtins.int
    ISVERTICALONLY_FIELD_NUMBER: builtins.int
    TITLEID_FIELD_NUMBER: builtins.int
    STARTFROMRIGHT_FIELD_NUMBER: builtins.int
    REGIONCODE_FIELD_NUMBER: builtins.int
    ISHORIZONTALONLY_FIELD_NUMBER: builtins.int
    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    PLANTYPE_FIELD_NUMBER: builtins.int
    TITLELANGUAGE_FIELD_NUMBER: builtins.int
    RATINGPOPUP_FIELD_NUMBER: builtins.int
    TITLEAVAILABLELANGUAGES_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    chapterId: builtins.int
    titleName: builtins.str
    chapterName: builtins.str
    numberOfComments: builtins.int
    isVerticalOnly: builtins.bool
    titleId: builtins.int
    startFromRight: builtins.bool
    regionCode: builtins.str
    isHorizontalOnly: builtins.bool
    planType: builtins.str
    titleLanguage: builtins.str
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]: ...
    @property
    def chapters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
    @property
    def sns(self) -> global___Sns: ...
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def ratingPopup(self) -> global___Popup: ...
    @property
    def titleAvailableLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MangaViewer.TitleAvailableLanguages]: ...
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        pages: collections.abc.Iterable[global___Page] | None = ...,
        chapterId: builtins.int = ...,
        chapters: collections.abc.Iterable[global___Chapter] | None = ...,
        sns: global___Sns | None = ...,
        titleName: builtins.str = ...,
        chapterName: builtins.str = ...,
        numberOfComments: builtins.int = ...,
        isVerticalOnly: builtins.bool = ...,
        titleId: builtins.int = ...,
        startFromRight: builtins.bool = ...,
        regionCode: builtins.str = ...,
        isHorizontalOnly: builtins.bool = ...,
        userSubscription: global___Subscription | None = ...,
        planType: builtins.str = ...,
        titleLanguage: builtins.str = ...,
        ratingPopup: global___Popup | None = ...,
        titleAvailableLanguages: collections.abc.Iterable[global___MangaViewer.TitleAvailableLanguages] | None = ...,
        title: global___Title | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ratingPopup", b"ratingPopup", "sns", b"sns", "title", b"title", "userSubscription", b"userSubscription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chapterId", b"chapterId", "chapterName", b"chapterName", "chapters", b"chapters", "isHorizontalOnly", b"isHorizontalOnly", "isVerticalOnly", b"isVerticalOnly", "numberOfComments", b"numberOfComments", "pages", b"pages", "planType", b"planType", "ratingPopup", b"ratingPopup", "regionCode", b"regionCode", "sns", b"sns", "startFromRight", b"startFromRight", "title", b"title", "titleAvailableLanguages", b"titleAvailableLanguages", "titleId", b"titleId", "titleLanguage", b"titleLanguage", "titleName", b"titleName", "userSubscription", b"userSubscription"]) -> None: ...

global___MangaViewer = MangaViewer

@typing.final
class MetaInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METATITLE_FIELD_NUMBER: builtins.int
    METADESCRIPTION_FIELD_NUMBER: builtins.int
    metaTitle: builtins.str
    metaDescription: builtins.str
    def __init__(
        self,
        *,
        metaTitle: builtins.str = ...,
        metaDescription: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["metaDescription", b"metaDescription", "metaTitle", b"metaTitle"]) -> None: ...

global___MetaInfo = MetaInfo

@typing.final
class MpcStatusView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISMPCMAINTENANCE_FIELD_NUMBER: builtins.int
    MAINTENANCEMESSAGE_FIELD_NUMBER: builtins.int
    isMpcMaintenance: builtins.bool
    maintenanceMessage: builtins.str
    def __init__(
        self,
        *,
        isMpcMaintenance: builtins.bool = ...,
        maintenanceMessage: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["isMpcMaintenance", b"isMpcMaintenance", "maintenanceMessage", b"maintenanceMessage"]) -> None: ...

global___MpcStatusView = MpcStatusView

@typing.final
class Page(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ChapterType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChapterTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Page._ChapterType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LATEST: Page._ChapterType.ValueType  # 0
        SEQUENCE: Page._ChapterType.ValueType  # 1
        NOSEQUENCE: Page._ChapterType.ValueType  # 2

    class ChapterType(_ChapterType, metaclass=_ChapterTypeEnumTypeWrapper): ...
    LATEST: Page.ChapterType.ValueType  # 0
    SEQUENCE: Page.ChapterType.ValueType  # 1
    NOSEQUENCE: Page.ChapterType.ValueType  # 2

    class _PageType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Page._PageType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SINGLE: Page._PageType.ValueType  # 0
        LEFT: Page._PageType.ValueType  # 1
        RIGHT: Page._PageType.ValueType  # 2
        DOUBLE: Page._PageType.ValueType  # 3

    class PageType(_PageType, metaclass=_PageTypeEnumTypeWrapper): ...
    SINGLE: Page.PageType.ValueType  # 0
    LEFT: Page.PageType.ValueType  # 1
    RIGHT: Page.PageType.ValueType  # 2
    DOUBLE: Page.PageType.ValueType  # 3

    class _DataCase:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DataCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Page._DataCase.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DATA_NOT_SET: Page._DataCase.ValueType  # 0
        MANGA_PAGE: Page._DataCase.ValueType  # 1
        BANNER_LIST: Page._DataCase.ValueType  # 2
        LAST_PAGE: Page._DataCase.ValueType  # 3
        ADVERTISEMENT: Page._DataCase.ValueType  # 4
        INSERT_BANNER_LIST: Page._DataCase.ValueType  # 5

    class DataCase(_DataCase, metaclass=_DataCaseEnumTypeWrapper): ...
    DATA_NOT_SET: Page.DataCase.ValueType  # 0
    MANGA_PAGE: Page.DataCase.ValueType  # 1
    BANNER_LIST: Page.DataCase.ValueType  # 2
    LAST_PAGE: Page.DataCase.ValueType  # 3
    ADVERTISEMENT: Page.DataCase.ValueType  # 4
    INSERT_BANNER_LIST: Page.DataCase.ValueType  # 5

    @typing.final
    class MangaPage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        IMAGEURL_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
        imageUrl: builtins.str
        width: builtins.int
        height: builtins.int
        type: global___Page.PageType.ValueType
        encryptionKey: builtins.str
        def __init__(
            self,
            *,
            imageUrl: builtins.str = ...,
            width: builtins.int = ...,
            height: builtins.int = ...,
            type: global___Page.PageType.ValueType = ...,
            encryptionKey: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["encryptionKey", b"encryptionKey", "height", b"height", "imageUrl", b"imageUrl", "type", b"type", "width", b"width"]) -> None: ...

    @typing.final
    class LastPage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CURRENTCHAPTER_FIELD_NUMBER: builtins.int
        NEXTCHAPTER_FIELD_NUMBER: builtins.int
        TOPCOMMENTS_FIELD_NUMBER: builtins.int
        ISSUBSCRIBED_FIELD_NUMBER: builtins.int
        NEXTTIMESTAMP_FIELD_NUMBER: builtins.int
        CHAPTERTYPE_FIELD_NUMBER: builtins.int
        ADVERTISEMENT_FIELD_NUMBER: builtins.int
        MOVIEREWARD_FIELD_NUMBER: builtins.int
        BANNERS_FIELD_NUMBER: builtins.int
        TICKETTITLELIST_FIELD_NUMBER: builtins.int
        PUBLISHERBANNER_FIELD_NUMBER: builtins.int
        USERTICKETS_FIELD_NUMBER: builtins.int
        ISNEXTCHAPTERREADBYTICKET_FIELD_NUMBER: builtins.int
        ISNEXTCHAPTERONETIMEFREE_FIELD_NUMBER: builtins.int
        FREEVIEWDIALOGUE_FIELD_NUMBER: builtins.int
        ISNEXTCHAPTERSUBSCRIPTION_FIELD_NUMBER: builtins.int
        ADVERTISEMENTREWARD_FIELD_NUMBER: builtins.int
        VIEWERENDADVERTISEMENT_FIELD_NUMBER: builtins.int
        isSubscribed: builtins.bool
        nextTimeStamp: builtins.int
        chapterType: global___Page.ChapterType.ValueType
        isNextChapterReadByTicket: builtins.bool
        isNextChapterOneTimeFree: builtins.bool
        isNextChapterSubscription: builtins.bool
        @property
        def currentChapter(self) -> global___Chapter: ...
        @property
        def nextChapter(self) -> global___Chapter: ...
        @property
        def topComments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Comment]: ...
        @property
        def advertisement(self) -> global___AdNetworkList: ...
        @property
        def movieReward(self) -> global___Popup: ...
        @property
        def banners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
        @property
        def ticketTitleList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
        @property
        def publisherBanner(self) -> global___Banner: ...
        @property
        def userTickets(self) -> global___UserTickets: ...
        @property
        def freeViewDialogue(self) -> global___FreeViewDialogue: ...
        @property
        def advertisementReward(self) -> global___AdRewardNetworkList: ...
        @property
        def viewerEndAdvertisement(self) -> global___AdNetworkList: ...
        def __init__(
            self,
            *,
            currentChapter: global___Chapter | None = ...,
            nextChapter: global___Chapter | None = ...,
            topComments: collections.abc.Iterable[global___Comment] | None = ...,
            isSubscribed: builtins.bool = ...,
            nextTimeStamp: builtins.int = ...,
            chapterType: global___Page.ChapterType.ValueType = ...,
            advertisement: global___AdNetworkList | None = ...,
            movieReward: global___Popup | None = ...,
            banners: collections.abc.Iterable[global___Banner] | None = ...,
            ticketTitleList: collections.abc.Iterable[global___Title] | None = ...,
            publisherBanner: global___Banner | None = ...,
            userTickets: global___UserTickets | None = ...,
            isNextChapterReadByTicket: builtins.bool = ...,
            isNextChapterOneTimeFree: builtins.bool = ...,
            freeViewDialogue: global___FreeViewDialogue | None = ...,
            isNextChapterSubscription: builtins.bool = ...,
            advertisementReward: global___AdRewardNetworkList | None = ...,
            viewerEndAdvertisement: global___AdNetworkList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["advertisement", b"advertisement", "advertisementReward", b"advertisementReward", "currentChapter", b"currentChapter", "freeViewDialogue", b"freeViewDialogue", "movieReward", b"movieReward", "nextChapter", b"nextChapter", "publisherBanner", b"publisherBanner", "userTickets", b"userTickets", "viewerEndAdvertisement", b"viewerEndAdvertisement"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "advertisementReward", b"advertisementReward", "banners", b"banners", "chapterType", b"chapterType", "currentChapter", b"currentChapter", "freeViewDialogue", b"freeViewDialogue", "isNextChapterOneTimeFree", b"isNextChapterOneTimeFree", "isNextChapterReadByTicket", b"isNextChapterReadByTicket", "isNextChapterSubscription", b"isNextChapterSubscription", "isSubscribed", b"isSubscribed", "movieReward", b"movieReward", "nextChapter", b"nextChapter", "nextTimeStamp", b"nextTimeStamp", "publisherBanner", b"publisherBanner", "ticketTitleList", b"ticketTitleList", "topComments", b"topComments", "userTickets", b"userTickets", "viewerEndAdvertisement", b"viewerEndAdvertisement"]) -> None: ...

    @typing.final
    class BannerList(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BANNERTITLE_FIELD_NUMBER: builtins.int
        BANNERS_FIELD_NUMBER: builtins.int
        bannerTitle: builtins.str
        @property
        def banners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
        def __init__(
            self,
            *,
            bannerTitle: builtins.str = ...,
            banners: collections.abc.Iterable[global___Banner] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["bannerTitle", b"bannerTitle", "banners", b"banners"]) -> None: ...

    MANGAPAGE_FIELD_NUMBER: builtins.int
    BANNERLIST_FIELD_NUMBER: builtins.int
    LASTPAGE_FIELD_NUMBER: builtins.int
    ADVERTISEMENT_FIELD_NUMBER: builtins.int
    INSERTBANNERLIST_FIELD_NUMBER: builtins.int
    @property
    def mangaPage(self) -> global___Page.MangaPage: ...
    @property
    def bannerList(self) -> global___Page.BannerList: ...
    @property
    def lastPage(self) -> global___Page.LastPage: ...
    @property
    def advertisement(self) -> global___AdRewardNetworkList: ...
    @property
    def insertBannerList(self) -> global___Page.BannerList: ...
    def __init__(
        self,
        *,
        mangaPage: global___Page.MangaPage | None = ...,
        bannerList: global___Page.BannerList | None = ...,
        lastPage: global___Page.LastPage | None = ...,
        advertisement: global___AdRewardNetworkList | None = ...,
        insertBannerList: global___Page.BannerList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advertisement", b"advertisement", "bannerList", b"bannerList", "insertBannerList", b"insertBannerList", "lastPage", b"lastPage", "mangaPage", b"mangaPage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "bannerList", b"bannerList", "insertBannerList", b"insertBannerList", "lastPage", b"lastPage", "mangaPage", b"mangaPage"]) -> None: ...

global___Page = Page

@typing.final
class Popup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PopupCase:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PopupCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Popup._PopupCase.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POPUP_NOT_SET: Popup._PopupCase.ValueType  # 0
        OS_DEFAULT: Popup._PopupCase.ValueType  # 1
        APP_DEFAULT: Popup._PopupCase.ValueType  # 2
        MOVIE_REWARD: Popup._PopupCase.ValueType  # 3
        ONE_IMAGE: Popup._PopupCase.ValueType  # 4

    class PopupCase(_PopupCase, metaclass=_PopupCaseEnumTypeWrapper): ...
    POPUP_NOT_SET: Popup.PopupCase.ValueType  # 0
    OS_DEFAULT: Popup.PopupCase.ValueType  # 1
    APP_DEFAULT: Popup.PopupCase.ValueType  # 2
    MOVIE_REWARD: Popup.PopupCase.ValueType  # 3
    ONE_IMAGE: Popup.PopupCase.ValueType  # 4

    @typing.final
    class OSDefault(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBJECT_FIELD_NUMBER: builtins.int
        BODY_FIELD_NUMBER: builtins.int
        OKBUTTON_FIELD_NUMBER: builtins.int
        NEUTRALBUTTON_FIELD_NUMBER: builtins.int
        CANCELBUTTON_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        subject: builtins.str
        body: builtins.str
        language: global___Language.ValueType
        @property
        def okButton(self) -> global___Popup.Button: ...
        @property
        def neutralButton(self) -> global___Popup.Button: ...
        @property
        def cancelButton(self) -> global___Popup.Button: ...
        def __init__(
            self,
            *,
            subject: builtins.str = ...,
            body: builtins.str = ...,
            okButton: global___Popup.Button | None = ...,
            neutralButton: global___Popup.Button | None = ...,
            cancelButton: global___Popup.Button | None = ...,
            language: global___Language.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["cancelButton", b"cancelButton", "neutralButton", b"neutralButton", "okButton", b"okButton"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["body", b"body", "cancelButton", b"cancelButton", "language", b"language", "neutralButton", b"neutralButton", "okButton", b"okButton", "subject", b"subject"]) -> None: ...

    @typing.final
    class AppDefault(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SUBJECT_FIELD_NUMBER: builtins.int
        BODY_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        IMAGEURL_FIELD_NUMBER: builtins.int
        subject: builtins.str
        body: builtins.str
        imageUrl: builtins.str
        @property
        def action(self) -> global___TransitionAction: ...
        def __init__(
            self,
            *,
            subject: builtins.str = ...,
            body: builtins.str = ...,
            action: global___TransitionAction | None = ...,
            imageUrl: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "body", b"body", "imageUrl", b"imageUrl", "subject", b"subject"]) -> None: ...

    @typing.final
    class OneImage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ACTION_FIELD_NUMBER: builtins.int
        IMAGEURL_FIELD_NUMBER: builtins.int
        imageUrl: builtins.str
        @property
        def action(self) -> global___TransitionAction: ...
        def __init__(
            self,
            *,
            action: global___TransitionAction | None = ...,
            imageUrl: builtins.str = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "imageUrl", b"imageUrl"]) -> None: ...

    @typing.final
    class Button(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TEXT_FIELD_NUMBER: builtins.int
        ACTION_FIELD_NUMBER: builtins.int
        text: builtins.str
        @property
        def action(self) -> global___TransitionAction: ...
        def __init__(
            self,
            *,
            text: builtins.str = ...,
            action: global___TransitionAction | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "text", b"text"]) -> None: ...

    OSDEFAULT_FIELD_NUMBER: builtins.int
    APPDEFAULT_FIELD_NUMBER: builtins.int
    MOVIEREWARD_FIELD_NUMBER: builtins.int
    ONEIMAGE_FIELD_NUMBER: builtins.int
    POPUPID_FIELD_NUMBER: builtins.int
    popupId: builtins.int
    @property
    def oSDefault(self) -> global___Popup.OSDefault: ...
    @property
    def appDefault(self) -> global___Popup.AppDefault: ...
    @property
    def movieReward(self) -> global___MovieReward: ...
    @property
    def oneImage(self) -> global___Popup.OneImage: ...
    def __init__(
        self,
        *,
        oSDefault: global___Popup.OSDefault | None = ...,
        appDefault: global___Popup.AppDefault | None = ...,
        movieReward: global___MovieReward | None = ...,
        oneImage: global___Popup.OneImage | None = ...,
        popupId: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["appDefault", b"appDefault", "movieReward", b"movieReward", "oSDefault", b"oSDefault", "oneImage", b"oneImage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["appDefault", b"appDefault", "movieReward", b"movieReward", "oSDefault", b"oSDefault", "oneImage", b"oneImage", "popupId", b"popupId"]) -> None: ...

global___Popup = Popup

@typing.final
class MovieReward(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGEURL_FIELD_NUMBER: builtins.int
    ADVERTISEMENT_FIELD_NUMBER: builtins.int
    imageUrl: builtins.str
    @property
    def advertisement(self) -> global___AdNetworkList: ...
    def __init__(
        self,
        *,
        imageUrl: builtins.str = ...,
        advertisement: global___AdNetworkList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advertisement", b"advertisement"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "imageUrl", b"imageUrl"]) -> None: ...

global___MovieReward = MovieReward

@typing.final
class ProfileSettingsView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ICONLIST_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    MYICON_FIELD_NUMBER: builtins.int
    userName: builtins.str
    @property
    def iconList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommentIcon]: ...
    @property
    def myIcon(self) -> global___CommentIcon: ...
    def __init__(
        self,
        *,
        iconList: collections.abc.Iterable[global___CommentIcon] | None = ...,
        userName: builtins.str = ...,
        myIcon: global___CommentIcon | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["myIcon", b"myIcon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["iconList", b"iconList", "myIcon", b"myIcon", "userName", b"userName"]) -> None: ...

global___ProfileSettingsView = ProfileSettingsView

@typing.final
class PublisherNewsListView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISHERID_FIELD_NUMBER: builtins.int
    PUBLISHERNAME_FIELD_NUMBER: builtins.int
    BANNER_FIELD_NUMBER: builtins.int
    NEWSLIST_FIELD_NUMBER: builtins.int
    publisherId: builtins.int
    publisherName: builtins.str
    @property
    def banner(self) -> global___Banner: ...
    @property
    def newsList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublisherNews]: ...
    def __init__(
        self,
        *,
        publisherId: builtins.int = ...,
        publisherName: builtins.str = ...,
        banner: global___Banner | None = ...,
        newsList: collections.abc.Iterable[global___PublisherNews] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["banner", b"banner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["banner", b"banner", "newsList", b"newsList", "publisherId", b"publisherId", "publisherName", b"publisherName"]) -> None: ...

global___PublisherNewsListView = PublisherNewsListView

@typing.final
class PublisherNews(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PUBLISHERID_FIELD_NUMBER: builtins.int
    PUBLISHERNAME_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    PUBLISHEDTIMESTAMP_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    id: builtins.int
    publisherId: builtins.int
    publisherName: builtins.str
    subject: builtins.str
    body: builtins.str
    publishedTimeStamp: builtins.int
    @property
    def action(self) -> global___TransitionAction: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        publisherId: builtins.int = ...,
        publisherName: builtins.str = ...,
        subject: builtins.str = ...,
        body: builtins.str = ...,
        publishedTimeStamp: builtins.int = ...,
        action: global___TransitionAction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "body", b"body", "id", b"id", "publishedTimeStamp", b"publishedTimeStamp", "publisherId", b"publisherId", "publisherName", b"publisherName", "subject", b"subject"]) -> None: ...

global___PublisherNews = PublisherNews

@typing.final
class PushTokenView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    TOKENTIMESTAMP_FIELD_NUMBER: builtins.int
    token: builtins.str
    tokenTimeStamp: builtins.int
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        tokenTimeStamp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["token", b"token", "tokenTimeStamp", b"tokenTimeStamp"]) -> None: ...

global___PushTokenView = PushTokenView

@typing.final
class Questionnaire(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    SELECTION_FIELD_NUMBER: builtins.int
    NUMBEROFCHOICES_FIELD_NUMBER: builtins.int
    HIDEFREEFORM_FIELD_NUMBER: builtins.int
    FREEFORM_FIELD_NUMBER: builtins.int
    CANSKIP_FIELD_NUMBER: builtins.int
    description: builtins.str
    numberOfChoices: builtins.int
    hideFreeform: builtins.bool
    freeForm: builtins.str
    canSkip: builtins.bool
    @property
    def selection(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        selection: collections.abc.Iterable[builtins.str] | None = ...,
        numberOfChoices: builtins.int = ...,
        hideFreeform: builtins.bool = ...,
        freeForm: builtins.str = ...,
        canSkip: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["canSkip", b"canSkip", "description", b"description", "freeForm", b"freeForm", "hideFreeform", b"hideFreeform", "numberOfChoices", b"numberOfChoices", "selection", b"selection"]) -> None: ...

global___Questionnaire = Questionnaire

@typing.final
class QuestionnaireView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISANSWERED_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    QUESTIONS_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    isAnswered: builtins.bool
    subject: builtins.str
    language: global___Language.ValueType
    @property
    def questions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Questionnaire]: ...
    def __init__(
        self,
        *,
        isAnswered: builtins.bool = ...,
        subject: builtins.str = ...,
        questions: collections.abc.Iterable[global___Questionnaire] | None = ...,
        language: global___Language.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["isAnswered", b"isAnswered", "language", b"language", "questions", b"questions", "subject", b"subject"]) -> None: ...

global___QuestionnaireView = QuestionnaireView

@typing.final
class RegistrationData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICESECRET_FIELD_NUMBER: builtins.int
    deviceSecret: builtins.str
    def __init__(
        self,
        *,
        deviceSecret: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deviceSecret", b"deviceSecret"]) -> None: ...

global___RegistrationData = RegistrationData

@typing.final
class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ResultCase:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResultCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Response._ResultCase.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RESULT_NOT_SET: Response._ResultCase.ValueType  # 0
        SUCCESS: Response._ResultCase.ValueType  # 1
        ERROR: Response._ResultCase.ValueType  # 2

    class ResultCase(_ResultCase, metaclass=_ResultCaseEnumTypeWrapper): ...
    RESULT_NOT_SET: Response.ResultCase.ValueType  # 0
    SUCCESS: Response.ResultCase.ValueType  # 1
    ERROR: Response.ResultCase.ValueType  # 2

    SUCCESS_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def success(self) -> global___SuccessResult: ...
    @property
    def error(self) -> global___ErrorResult: ...
    def __init__(
        self,
        *,
        success: global___SuccessResult | None = ...,
        error: global___ErrorResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["error", b"error", "success", b"success"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["error", b"error", "success", b"success"]) -> None: ...

global___Response = Response

@typing.final
class SearchView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Contents(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BANNER_FIELD_NUMBER: builtins.int
        TITLELIST_FIELD_NUMBER: builtins.int
        RANKEDTITLES_FIELD_NUMBER: builtins.int
        ALLLABELS_FIELD_NUMBER: builtins.int
        CHAPTERPAGESLIST_FIELD_NUMBER: builtins.int
        @property
        def banner(self) -> global___Banner: ...
        @property
        def titleList(self) -> global___TitleList: ...
        @property
        def rankedTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
        @property
        def allLabels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Label]: ...
        @property
        def chapterPagesList(self) -> global___ChapterPageList: ...
        def __init__(
            self,
            *,
            banner: global___Banner | None = ...,
            titleList: global___TitleList | None = ...,
            rankedTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
            allLabels: collections.abc.Iterable[global___Label] | None = ...,
            chapterPagesList: global___ChapterPageList | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["banner", b"banner", "chapterPagesList", b"chapterPagesList", "titleList", b"titleList"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["allLabels", b"allLabels", "banner", b"banner", "chapterPagesList", b"chapterPagesList", "rankedTitles", b"rankedTitles", "titleList", b"titleList"]) -> None: ...

    TOPSEARCHBANNERS_FIELD_NUMBER: builtins.int
    ALLTAGS_FIELD_NUMBER: builtins.int
    ALLTITLESGROUP_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    @property
    def topSearchBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def allTags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]: ...
    @property
    def allTitlesGroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AllTitlesGroup]: ...
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchView.Contents]: ...
    def __init__(
        self,
        *,
        topSearchBanners: collections.abc.Iterable[global___Banner] | None = ...,
        allTags: collections.abc.Iterable[global___Tag] | None = ...,
        allTitlesGroup: collections.abc.Iterable[global___AllTitlesGroup] | None = ...,
        contents: collections.abc.Iterable[global___SearchView.Contents] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["allTags", b"allTags", "allTitlesGroup", b"allTitlesGroup", "contents", b"contents", "topSearchBanners", b"topSearchBanners"]) -> None: ...

global___SearchView = SearchView

@typing.final
class ServiceAnnouncement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    DATE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    title: builtins.str
    body: builtins.str
    date: builtins.int
    id: builtins.int
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        body: builtins.str = ...,
        date: builtins.int = ...,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "date", b"date", "id", b"id", "title", b"title"]) -> None: ...

global___ServiceAnnouncement = ServiceAnnouncement

@typing.final
class ServiceAnnouncementsView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICEANNOUNCEMENTS_FIELD_NUMBER: builtins.int
    @property
    def serviceAnnouncements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAnnouncement]: ...
    def __init__(
        self,
        *,
        serviceAnnouncements: collections.abc.Iterable[global___ServiceAnnouncement] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["serviceAnnouncements", b"serviceAnnouncements"]) -> None: ...

global___ServiceAnnouncementsView = ServiceAnnouncementsView

@typing.final
class SettingsView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MYICON_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    NOTICEOFNEWSANDEVENTS_FIELD_NUMBER: builtins.int
    NOTICEOFUPDATESOFSUBSCRIBEDTITLES_FIELD_NUMBER: builtins.int
    ENGLISHTITLESCOUNT_FIELD_NUMBER: builtins.int
    SPANISHTITLESCOUNT_FIELD_NUMBER: builtins.int
    userName: builtins.str
    noticeOfNewsAndEvents: builtins.bool
    noticeOfUpdatesOfSubscribedTitles: builtins.bool
    englishTitlesCount: builtins.int
    spanishTitlesCount: builtins.int
    @property
    def myIcon(self) -> global___CommentIcon: ...
    def __init__(
        self,
        *,
        myIcon: global___CommentIcon | None = ...,
        userName: builtins.str = ...,
        noticeOfNewsAndEvents: builtins.bool = ...,
        noticeOfUpdatesOfSubscribedTitles: builtins.bool = ...,
        englishTitlesCount: builtins.int = ...,
        spanishTitlesCount: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["myIcon", b"myIcon"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["englishTitlesCount", b"englishTitlesCount", "myIcon", b"myIcon", "noticeOfNewsAndEvents", b"noticeOfNewsAndEvents", "noticeOfUpdatesOfSubscribedTitles", b"noticeOfUpdatesOfSubscribedTitles", "spanishTitlesCount", b"spanishTitlesCount", "userName", b"userName"]) -> None: ...

global___SettingsView = SettingsView

@typing.final
class SettingsViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MYICON_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    NOTICEOFNEWSANDEVENTS_FIELD_NUMBER: builtins.int
    NOTICEOFUPDATESOFSUBSCRIBEDTITLES_FIELD_NUMBER: builtins.int
    AVAILABLELANGUAGES_FIELD_NUMBER: builtins.int
    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    BANNER_FIELD_NUMBER: builtins.int
    AVAILABLECUSTOMCODES_FIELD_NUMBER: builtins.int
    FAVORITETITLES_FIELD_NUMBER: builtins.int
    userName: builtins.str
    noticeOfNewsAndEvents: builtins.bool
    noticeOfUpdatesOfSubscribedTitles: builtins.bool
    @property
    def myIcon(self) -> global___CommentIcon: ...
    @property
    def availableLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailableLanguages]: ...
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def banner(self) -> global___Banner: ...
    @property
    def availableCustomCodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomCodeDialogue]: ...
    @property
    def favoriteTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
    def __init__(
        self,
        *,
        myIcon: global___CommentIcon | None = ...,
        userName: builtins.str = ...,
        noticeOfNewsAndEvents: builtins.bool = ...,
        noticeOfUpdatesOfSubscribedTitles: builtins.bool = ...,
        availableLanguages: collections.abc.Iterable[global___AvailableLanguages] | None = ...,
        userSubscription: global___Subscription | None = ...,
        banner: global___Banner | None = ...,
        availableCustomCodes: collections.abc.Iterable[global___CustomCodeDialogue] | None = ...,
        favoriteTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["banner", b"banner", "myIcon", b"myIcon", "userSubscription", b"userSubscription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["availableCustomCodes", b"availableCustomCodes", "availableLanguages", b"availableLanguages", "banner", b"banner", "favoriteTitles", b"favoriteTitles", "myIcon", b"myIcon", "noticeOfNewsAndEvents", b"noticeOfNewsAndEvents", "noticeOfUpdatesOfSubscribedTitles", b"noticeOfUpdatesOfSubscribedTitles", "userName", b"userName", "userSubscription", b"userSubscription"]) -> None: ...

global___SettingsViewV2 = SettingsViewV2

@typing.final
class CustomCodeDialogue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLANTYPE_FIELD_NUMBER: builtins.int
    planType: builtins.str
    def __init__(
        self,
        *,
        planType: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["planType", b"planType"]) -> None: ...

global___CustomCodeDialogue = CustomCodeDialogue

@typing.final
class Sns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    body: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        body: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["body", b"body", "url", b"url"]) -> None: ...

global___Sns = Sns

@typing.final
class SubscribedTitlesView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLES_FIELD_NUMBER: builtins.int
    HISTORYBANNERS_FIELD_NUMBER: builtins.int
    VIEWHISTORY_FIELD_NUMBER: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    @property
    def historyBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def viewHistory(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        titles: collections.abc.Iterable[global___Title] | None = ...,
        historyBanners: collections.abc.Iterable[global___Banner] | None = ...,
        viewHistory: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["historyBanners", b"historyBanners", "titles", b"titles", "viewHistory", b"viewHistory"]) -> None: ...

global___SubscribedTitlesView = SubscribedTitlesView

@typing.final
class IosSubscriptionOffer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _OfferType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OfferTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[IosSubscriptionOffer._OfferType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NO_OFFER: IosSubscriptionOffer._OfferType.ValueType  # 0
        INTRODUCTORY: IosSubscriptionOffer._OfferType.ValueType  # 1
        PROMOTIONAL: IosSubscriptionOffer._OfferType.ValueType  # 2

    class OfferType(_OfferType, metaclass=_OfferTypeEnumTypeWrapper): ...
    NO_OFFER: IosSubscriptionOffer.OfferType.ValueType  # 0
    INTRODUCTORY: IosSubscriptionOffer.OfferType.ValueType  # 1
    PROMOTIONAL: IosSubscriptionOffer.OfferType.ValueType  # 2

    OFFERTYPE_FIELD_NUMBER: builtins.int
    SIGNATURE_FIELD_NUMBER: builtins.int
    APPLEKEY_FIELD_NUMBER: builtins.int
    NONCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    offerType: global___IosSubscriptionOffer.OfferType.ValueType
    signature: builtins.str
    appleKey: builtins.str
    nonce: builtins.str
    timestamp: builtins.str
    identifier: builtins.str
    def __init__(
        self,
        *,
        offerType: global___IosSubscriptionOffer.OfferType.ValueType = ...,
        signature: builtins.str = ...,
        appleKey: builtins.str = ...,
        nonce: builtins.str = ...,
        timestamp: builtins.str = ...,
        identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["appleKey", b"appleKey", "identifier", b"identifier", "nonce", b"nonce", "offerType", b"offerType", "signature", b"signature", "timestamp", b"timestamp"]) -> None: ...

global___IosSubscriptionOffer = IosSubscriptionOffer

@typing.final
class AndroidSubscriptionOfferTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    tag: builtins.str
    def __init__(
        self,
        *,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tag", b"tag"]) -> None: ...

global___AndroidSubscriptionOfferTags = AndroidSubscriptionOfferTags

@typing.final
class Subscription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLANTYPE_FIELD_NUMBER: builtins.int
    NEXTPAYMENTDATE_FIELD_NUMBER: builtins.int
    ISFREETRIAL_FIELD_NUMBER: builtins.int
    ISPENDINGDOWNGRADE_FIELD_NUMBER: builtins.int
    ISFIRSTTIMEUSER_FIELD_NUMBER: builtins.int
    planType: builtins.str
    nextPaymentDate: builtins.int
    isFreeTrial: builtins.bool
    isPendingDowngrade: builtins.bool
    isFirstTimeUser: builtins.bool
    def __init__(
        self,
        *,
        planType: builtins.str = ...,
        nextPaymentDate: builtins.int = ...,
        isFreeTrial: builtins.bool = ...,
        isPendingDowngrade: builtins.bool = ...,
        isFirstTimeUser: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["isFirstTimeUser", b"isFirstTimeUser", "isFreeTrial", b"isFreeTrial", "isPendingDowngrade", b"isPendingDowngrade", "nextPaymentDate", b"nextPaymentDate", "planType", b"planType"]) -> None: ...

global___Subscription = Subscription

@typing.final
class PlanType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAN_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PRODUCTID_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONOFFER_FIELD_NUMBER: builtins.int
    ANDROIDOFFERTAGS_FIELD_NUMBER: builtins.int
    plan: builtins.str
    description: builtins.str
    productId: builtins.str
    @property
    def subscriptionOffer(self) -> global___IosSubscriptionOffer: ...
    @property
    def androidOfferTags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AndroidSubscriptionOfferTags]: ...
    def __init__(
        self,
        *,
        plan: builtins.str = ...,
        description: builtins.str = ...,
        productId: builtins.str = ...,
        subscriptionOffer: global___IosSubscriptionOffer | None = ...,
        androidOfferTags: collections.abc.Iterable[global___AndroidSubscriptionOfferTags] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["subscriptionOffer", b"subscriptionOffer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["androidOfferTags", b"androidOfferTags", "description", b"description", "plan", b"plan", "productId", b"productId", "subscriptionOffer", b"subscriptionOffer"]) -> None: ...

global___PlanType = PlanType

@typing.final
class SubscriptionView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    PLANTYPES_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONTITLES_FIELD_NUMBER: builtins.int
    USERHASUSEDTRIAL_FIELD_NUMBER: builtins.int
    BANNER_FIELD_NUMBER: builtins.int
    PLANBOXDESCRIPTION_FIELD_NUMBER: builtins.int
    NOTE_FIELD_NUMBER: builtins.int
    userHasUsedTrial: builtins.bool
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def planTypes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlanType]: ...
    @property
    def subscriptionTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleSubscriptionGroup]: ...
    @property
    def banner(self) -> global___Banner: ...
    @property
    def planBoxDescription(self) -> global___SubscriptionPlanBoxDescription: ...
    @property
    def note(self) -> global___SubscriptionNote: ...
    def __init__(
        self,
        *,
        userSubscription: global___Subscription | None = ...,
        planTypes: collections.abc.Iterable[global___PlanType] | None = ...,
        subscriptionTitles: collections.abc.Iterable[global___TitleSubscriptionGroup] | None = ...,
        userHasUsedTrial: builtins.bool = ...,
        banner: global___Banner | None = ...,
        planBoxDescription: global___SubscriptionPlanBoxDescription | None = ...,
        note: global___SubscriptionNote | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["banner", b"banner", "note", b"note", "planBoxDescription", b"planBoxDescription", "userSubscription", b"userSubscription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["banner", b"banner", "note", b"note", "planBoxDescription", b"planBoxDescription", "planTypes", b"planTypes", "subscriptionTitles", b"subscriptionTitles", "userHasUsedTrial", b"userHasUsedTrial", "userSubscription", b"userSubscription"]) -> None: ...

global___SubscriptionView = SubscriptionView

@typing.final
class SubscriptionPlanBoxDescription(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    text: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text", "title", b"title"]) -> None: ...

global___SubscriptionPlanBoxDescription = SubscriptionPlanBoxDescription

@typing.final
class SubscriptionNote(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    title: builtins.str
    text: builtins.str
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text", "title", b"title"]) -> None: ...

global___SubscriptionNote = SubscriptionNote

@typing.final
class SuccessResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _DataCase:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DataCaseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SuccessResult._DataCase.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DATA_NOT_SET: SuccessResult._DataCase.ValueType  # 0
        REGISTERATION_DATA: SuccessResult._DataCase.ValueType  # 2
        FEATURED_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 4
        ALL_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 5
        TITLE_RANKING_VIEW: SuccessResult._DataCase.ValueType  # 6
        SUBSCRIBED_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 7
        TITLE_DETAIL_VIEW: SuccessResult._DataCase.ValueType  # 8
        COMMENT_LIST_VIEW: SuccessResult._DataCase.ValueType  # 9
        MANGA_VIEWER: SuccessResult._DataCase.ValueType  # 10
        PROFILE_SETTINGS_VIEW: SuccessResult._DataCase.ValueType  # 13
        UPDATE_PROFILE_RESULT_VIEW: SuccessResult._DataCase.ValueType  # 14
        SERVICE_ANNOUNCEMENTS_VIEW: SuccessResult._DataCase.ValueType  # 15
        FEEDBACK_VIEW: SuccessResult._DataCase.ValueType  # 17
        PUBLISHER_NEWS_LIST_VIEW: SuccessResult._DataCase.ValueType  # 18
        QUESTIONNAIRE_VIEW: SuccessResult._DataCase.ValueType  # 19
        TITLE_UPDATED_VIEW: SuccessResult._DataCase.ValueType  # 20
        UPDATED_TITLE_LIST_VIEW: SuccessResult._DataCase.ValueType  # 22
        ALL_TICKET_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 23
        HOME_VIEW_V3: SuccessResult._DataCase.ValueType  # 24
        ALL_TITLES_VIEW_V2: SuccessResult._DataCase.ValueType  # 25
        SETTINGS_VIEW_V2: SuccessResult._DataCase.ValueType  # 26
        TITLE_LIST_VIEW_V2: SuccessResult._DataCase.ValueType  # 27
        INITIAL_VIEW_V2: SuccessResult._DataCase.ValueType  # 28
        PUSH_TOKEN_VIEW: SuccessResult._DataCase.ValueType  # 32
        ALL_FREE_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 33
        LABELED_VIEW: SuccessResult._DataCase.ValueType  # 34
        SEARCH_VIEW: SuccessResult._DataCase.ValueType  # 35
        SUBSCRIPTION_VIEW: SuccessResult._DataCase.ValueType  # 36
        TITLE_RANKING_VIEW_V2: SuccessResult._DataCase.ValueType  # 37
        WEB_HOME_VIEW_V4: SuccessResult._DataCase.ValueType  # 38
        FEATURED_TITLES_VIEW_V2: SuccessResult._DataCase.ValueType  # 39
        HISTORY_VIEW: SuccessResult._DataCase.ValueType  # 40
        DOWNLOADABLE_IMAGES_VIEW: SuccessResult._DataCase.ValueType  # 41
        INTRODUCE_SUBSCRIPTION: SuccessResult._DataCase.ValueType  # 42
        FAVORITE_TITLES_VIEW: SuccessResult._DataCase.ValueType  # 43
        MPC_STATUS_VIEW: SuccessResult._DataCase.ValueType  # 44
        HOME_VIEW_V4: SuccessResult._DataCase.ValueType  # 45

    class DataCase(_DataCase, metaclass=_DataCaseEnumTypeWrapper): ...
    DATA_NOT_SET: SuccessResult.DataCase.ValueType  # 0
    REGISTERATION_DATA: SuccessResult.DataCase.ValueType  # 2
    FEATURED_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 4
    ALL_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 5
    TITLE_RANKING_VIEW: SuccessResult.DataCase.ValueType  # 6
    SUBSCRIBED_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 7
    TITLE_DETAIL_VIEW: SuccessResult.DataCase.ValueType  # 8
    COMMENT_LIST_VIEW: SuccessResult.DataCase.ValueType  # 9
    MANGA_VIEWER: SuccessResult.DataCase.ValueType  # 10
    PROFILE_SETTINGS_VIEW: SuccessResult.DataCase.ValueType  # 13
    UPDATE_PROFILE_RESULT_VIEW: SuccessResult.DataCase.ValueType  # 14
    SERVICE_ANNOUNCEMENTS_VIEW: SuccessResult.DataCase.ValueType  # 15
    FEEDBACK_VIEW: SuccessResult.DataCase.ValueType  # 17
    PUBLISHER_NEWS_LIST_VIEW: SuccessResult.DataCase.ValueType  # 18
    QUESTIONNAIRE_VIEW: SuccessResult.DataCase.ValueType  # 19
    TITLE_UPDATED_VIEW: SuccessResult.DataCase.ValueType  # 20
    UPDATED_TITLE_LIST_VIEW: SuccessResult.DataCase.ValueType  # 22
    ALL_TICKET_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 23
    HOME_VIEW_V3: SuccessResult.DataCase.ValueType  # 24
    ALL_TITLES_VIEW_V2: SuccessResult.DataCase.ValueType  # 25
    SETTINGS_VIEW_V2: SuccessResult.DataCase.ValueType  # 26
    TITLE_LIST_VIEW_V2: SuccessResult.DataCase.ValueType  # 27
    INITIAL_VIEW_V2: SuccessResult.DataCase.ValueType  # 28
    PUSH_TOKEN_VIEW: SuccessResult.DataCase.ValueType  # 32
    ALL_FREE_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 33
    LABELED_VIEW: SuccessResult.DataCase.ValueType  # 34
    SEARCH_VIEW: SuccessResult.DataCase.ValueType  # 35
    SUBSCRIPTION_VIEW: SuccessResult.DataCase.ValueType  # 36
    TITLE_RANKING_VIEW_V2: SuccessResult.DataCase.ValueType  # 37
    WEB_HOME_VIEW_V4: SuccessResult.DataCase.ValueType  # 38
    FEATURED_TITLES_VIEW_V2: SuccessResult.DataCase.ValueType  # 39
    HISTORY_VIEW: SuccessResult.DataCase.ValueType  # 40
    DOWNLOADABLE_IMAGES_VIEW: SuccessResult.DataCase.ValueType  # 41
    INTRODUCE_SUBSCRIPTION: SuccessResult.DataCase.ValueType  # 42
    FAVORITE_TITLES_VIEW: SuccessResult.DataCase.ValueType  # 43
    MPC_STATUS_VIEW: SuccessResult.DataCase.ValueType  # 44
    HOME_VIEW_V4: SuccessResult.DataCase.ValueType  # 45

    ISFEATUREDUPDATED_FIELD_NUMBER: builtins.int
    REGISTERATIONDATA_FIELD_NUMBER: builtins.int
    FEATUREDTITLESVIEW_FIELD_NUMBER: builtins.int
    ALLTITLESVIEW_FIELD_NUMBER: builtins.int
    TITLERANKINGVIEW_FIELD_NUMBER: builtins.int
    SUBSCRIBEDTITLESVIEW_FIELD_NUMBER: builtins.int
    TITLEDETAILVIEW_FIELD_NUMBER: builtins.int
    COMMENTLISTVIEW_FIELD_NUMBER: builtins.int
    MANGAVIEWER_FIELD_NUMBER: builtins.int
    PROFILESETTINGSVIEW_FIELD_NUMBER: builtins.int
    UPDATEPROFILERESULTVIEW_FIELD_NUMBER: builtins.int
    SERVICEANNOUNCEMENTSVIEW_FIELD_NUMBER: builtins.int
    FEEDBACKVIEW_FIELD_NUMBER: builtins.int
    PUBLISHERNEWSLISTVIEW_FIELD_NUMBER: builtins.int
    QUESTIONNAIREVIEW_FIELD_NUMBER: builtins.int
    TITLEUPDATEDVIEW_FIELD_NUMBER: builtins.int
    UPDATEDTITLELISTVIEW_FIELD_NUMBER: builtins.int
    ALLTICKETTITLESVIEW_FIELD_NUMBER: builtins.int
    HOMEVIEWV3_FIELD_NUMBER: builtins.int
    ALLTITLESVIEWV2_FIELD_NUMBER: builtins.int
    SETTINGSVIEWV2_FIELD_NUMBER: builtins.int
    TITLELISTVIEWV2_FIELD_NUMBER: builtins.int
    INITIALVIEWV2_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    PUSHTOKENVIEW_FIELD_NUMBER: builtins.int
    ALLFREETITLESVIEW_FIELD_NUMBER: builtins.int
    LABELEDVIEW_FIELD_NUMBER: builtins.int
    SEARCHVIEW_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONVIEW_FIELD_NUMBER: builtins.int
    TITLERANKINGVIEWV2_FIELD_NUMBER: builtins.int
    WEBHOMEVIEWV4_FIELD_NUMBER: builtins.int
    FEATUREDTITLESVIEWV2_FIELD_NUMBER: builtins.int
    HISTORYVIEW_FIELD_NUMBER: builtins.int
    DOWNLOADABLEIMAGESVIEW_FIELD_NUMBER: builtins.int
    INTRODUCESUBSCRIPTION_FIELD_NUMBER: builtins.int
    FAVORITETITLESVIEW_FIELD_NUMBER: builtins.int
    MPCSTATUSVIEW_FIELD_NUMBER: builtins.int
    HOMEVIEWV4_FIELD_NUMBER: builtins.int
    isFeaturedUpdated: builtins.bool
    @property
    def registerationData(self) -> global___RegistrationData: ...
    @property
    def featuredTitlesView(self) -> global___FeaturedTitlesView: ...
    @property
    def allTitlesView(self) -> global___AllTitlesView: ...
    @property
    def titleRankingView(self) -> global___TitleRankingView: ...
    @property
    def subscribedTitlesView(self) -> global___SubscribedTitlesView: ...
    @property
    def titleDetailView(self) -> global___TitleDetailView: ...
    @property
    def commentListView(self) -> global___CommentListView: ...
    @property
    def mangaViewer(self) -> global___MangaViewer: ...
    @property
    def profileSettingsView(self) -> global___ProfileSettingsView: ...
    @property
    def updateProfileResultView(self) -> global___UpdateProfileResultView: ...
    @property
    def serviceAnnouncementsView(self) -> global___ServiceAnnouncementsView: ...
    @property
    def feedbackView(self) -> global___FeedbackView: ...
    @property
    def publisherNewsListView(self) -> global___PublisherNewsListView: ...
    @property
    def questionnaireView(self) -> global___QuestionnaireView: ...
    @property
    def titleUpdatedView(self) -> global___TitleUpdatedView: ...
    @property
    def updatedTitleListView(self) -> global___UpdatedTitleListView: ...
    @property
    def allTicketTitlesView(self) -> global___AllTicketTitlesView: ...
    @property
    def homeViewV3(self) -> global___HomeViewV3: ...
    @property
    def allTitlesViewV2(self) -> global___AllTitlesViewV2: ...
    @property
    def settingsViewV2(self) -> global___SettingsViewV2: ...
    @property
    def titleListViewV2(self) -> global___TitleUpdatedViewV2: ...
    @property
    def initialViewV2(self) -> global___InitialViewV2: ...
    @property
    def languages(self) -> global___Languages: ...
    @property
    def pushTokenView(self) -> global___PushTokenView: ...
    @property
    def allFreeTitlesView(self) -> global___AllFreeTitlesView: ...
    @property
    def labeledView(self) -> global___LabeledView: ...
    @property
    def searchView(self) -> global___SearchView: ...
    @property
    def subscriptionView(self) -> global___SubscriptionView: ...
    @property
    def titleRankingViewV2(self) -> global___TitleRankingViewV2: ...
    @property
    def webHomeViewV4(self) -> global___WebHomeViewV4: ...
    @property
    def featuredTitlesViewV2(self) -> global___FeaturedTitlesViewV2: ...
    @property
    def historyView(self) -> global___HistoryView: ...
    @property
    def downloadableImagesView(self) -> global___DownloadableImagesView: ...
    @property
    def introduceSubscription(self) -> global___IntroduceSubscription: ...
    @property
    def favoriteTitlesView(self) -> global___FavoriteTitlesView: ...
    @property
    def mpcStatusView(self) -> global___MpcStatusView: ...
    @property
    def homeViewV4(self) -> global___HomeViewV4: ...
    def __init__(
        self,
        *,
        isFeaturedUpdated: builtins.bool = ...,
        registerationData: global___RegistrationData | None = ...,
        featuredTitlesView: global___FeaturedTitlesView | None = ...,
        allTitlesView: global___AllTitlesView | None = ...,
        titleRankingView: global___TitleRankingView | None = ...,
        subscribedTitlesView: global___SubscribedTitlesView | None = ...,
        titleDetailView: global___TitleDetailView | None = ...,
        commentListView: global___CommentListView | None = ...,
        mangaViewer: global___MangaViewer | None = ...,
        profileSettingsView: global___ProfileSettingsView | None = ...,
        updateProfileResultView: global___UpdateProfileResultView | None = ...,
        serviceAnnouncementsView: global___ServiceAnnouncementsView | None = ...,
        feedbackView: global___FeedbackView | None = ...,
        publisherNewsListView: global___PublisherNewsListView | None = ...,
        questionnaireView: global___QuestionnaireView | None = ...,
        titleUpdatedView: global___TitleUpdatedView | None = ...,
        updatedTitleListView: global___UpdatedTitleListView | None = ...,
        allTicketTitlesView: global___AllTicketTitlesView | None = ...,
        homeViewV3: global___HomeViewV3 | None = ...,
        allTitlesViewV2: global___AllTitlesViewV2 | None = ...,
        settingsViewV2: global___SettingsViewV2 | None = ...,
        titleListViewV2: global___TitleUpdatedViewV2 | None = ...,
        initialViewV2: global___InitialViewV2 | None = ...,
        languages: global___Languages | None = ...,
        pushTokenView: global___PushTokenView | None = ...,
        allFreeTitlesView: global___AllFreeTitlesView | None = ...,
        labeledView: global___LabeledView | None = ...,
        searchView: global___SearchView | None = ...,
        subscriptionView: global___SubscriptionView | None = ...,
        titleRankingViewV2: global___TitleRankingViewV2 | None = ...,
        webHomeViewV4: global___WebHomeViewV4 | None = ...,
        featuredTitlesViewV2: global___FeaturedTitlesViewV2 | None = ...,
        historyView: global___HistoryView | None = ...,
        downloadableImagesView: global___DownloadableImagesView | None = ...,
        introduceSubscription: global___IntroduceSubscription | None = ...,
        favoriteTitlesView: global___FavoriteTitlesView | None = ...,
        mpcStatusView: global___MpcStatusView | None = ...,
        homeViewV4: global___HomeViewV4 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allFreeTitlesView", b"allFreeTitlesView", "allTicketTitlesView", b"allTicketTitlesView", "allTitlesView", b"allTitlesView", "allTitlesViewV2", b"allTitlesViewV2", "commentListView", b"commentListView", "downloadableImagesView", b"downloadableImagesView", "favoriteTitlesView", b"favoriteTitlesView", "featuredTitlesView", b"featuredTitlesView", "featuredTitlesViewV2", b"featuredTitlesViewV2", "feedbackView", b"feedbackView", "historyView", b"historyView", "homeViewV3", b"homeViewV3", "homeViewV4", b"homeViewV4", "initialViewV2", b"initialViewV2", "introduceSubscription", b"introduceSubscription", "labeledView", b"labeledView", "languages", b"languages", "mangaViewer", b"mangaViewer", "mpcStatusView", b"mpcStatusView", "profileSettingsView", b"profileSettingsView", "publisherNewsListView", b"publisherNewsListView", "pushTokenView", b"pushTokenView", "questionnaireView", b"questionnaireView", "registerationData", b"registerationData", "searchView", b"searchView", "serviceAnnouncementsView", b"serviceAnnouncementsView", "settingsViewV2", b"settingsViewV2", "subscribedTitlesView", b"subscribedTitlesView", "subscriptionView", b"subscriptionView", "titleDetailView", b"titleDetailView", "titleListViewV2", b"titleListViewV2", "titleRankingView", b"titleRankingView", "titleRankingViewV2", b"titleRankingViewV2", "titleUpdatedView", b"titleUpdatedView", "updateProfileResultView", b"updateProfileResultView", "updatedTitleListView", b"updatedTitleListView", "webHomeViewV4", b"webHomeViewV4"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allFreeTitlesView", b"allFreeTitlesView", "allTicketTitlesView", b"allTicketTitlesView", "allTitlesView", b"allTitlesView", "allTitlesViewV2", b"allTitlesViewV2", "commentListView", b"commentListView", "downloadableImagesView", b"downloadableImagesView", "favoriteTitlesView", b"favoriteTitlesView", "featuredTitlesView", b"featuredTitlesView", "featuredTitlesViewV2", b"featuredTitlesViewV2", "feedbackView", b"feedbackView", "historyView", b"historyView", "homeViewV3", b"homeViewV3", "homeViewV4", b"homeViewV4", "initialViewV2", b"initialViewV2", "introduceSubscription", b"introduceSubscription", "isFeaturedUpdated", b"isFeaturedUpdated", "labeledView", b"labeledView", "languages", b"languages", "mangaViewer", b"mangaViewer", "mpcStatusView", b"mpcStatusView", "profileSettingsView", b"profileSettingsView", "publisherNewsListView", b"publisherNewsListView", "pushTokenView", b"pushTokenView", "questionnaireView", b"questionnaireView", "registerationData", b"registerationData", "searchView", b"searchView", "serviceAnnouncementsView", b"serviceAnnouncementsView", "settingsViewV2", b"settingsViewV2", "subscribedTitlesView", b"subscribedTitlesView", "subscriptionView", b"subscriptionView", "titleDetailView", b"titleDetailView", "titleListViewV2", b"titleListViewV2", "titleRankingView", b"titleRankingView", "titleRankingViewV2", b"titleRankingViewV2", "titleUpdatedView", b"titleUpdatedView", "updateProfileResultView", b"updateProfileResultView", "updatedTitleListView", b"updatedTitleListView", "webHomeViewV4", b"webHomeViewV4"]) -> None: ...

global___SuccessResult = SuccessResult

@typing.final
class Tag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    SLUG_FIELD_NUMBER: builtins.int
    tag: builtins.str
    slug: builtins.str
    def __init__(
        self,
        *,
        tag: builtins.str = ...,
        slug: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["slug", b"slug", "tag", b"tag"]) -> None: ...

global___Tag = Tag

@typing.final
class TitleDetailView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ReleaseSchedule:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReleaseScheduleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleDetailView._ReleaseSchedule.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DISABLED: TitleDetailView._ReleaseSchedule.ValueType  # 0
        EVERYDAY: TitleDetailView._ReleaseSchedule.ValueType  # 1
        WEEKLY: TitleDetailView._ReleaseSchedule.ValueType  # 2
        BIWEEKLY: TitleDetailView._ReleaseSchedule.ValueType  # 3
        MONTHLY: TitleDetailView._ReleaseSchedule.ValueType  # 4
        BIMONTHLY: TitleDetailView._ReleaseSchedule.ValueType  # 5
        TRIMONTHLY: TitleDetailView._ReleaseSchedule.ValueType  # 6
        OTHER: TitleDetailView._ReleaseSchedule.ValueType  # 7
        COMPLETED: TitleDetailView._ReleaseSchedule.ValueType  # 8

    class ReleaseSchedule(_ReleaseSchedule, metaclass=_ReleaseScheduleEnumTypeWrapper): ...
    DISABLED: TitleDetailView.ReleaseSchedule.ValueType  # 0
    EVERYDAY: TitleDetailView.ReleaseSchedule.ValueType  # 1
    WEEKLY: TitleDetailView.ReleaseSchedule.ValueType  # 2
    BIWEEKLY: TitleDetailView.ReleaseSchedule.ValueType  # 3
    MONTHLY: TitleDetailView.ReleaseSchedule.ValueType  # 4
    BIMONTHLY: TitleDetailView.ReleaseSchedule.ValueType  # 5
    TRIMONTHLY: TitleDetailView.ReleaseSchedule.ValueType  # 6
    OTHER: TitleDetailView.ReleaseSchedule.ValueType  # 7
    COMPLETED: TitleDetailView.ReleaseSchedule.ValueType  # 8

    class _UpdateTiming:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _UpdateTimingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleDetailView._UpdateTiming.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_REGULARLY: TitleDetailView._UpdateTiming.ValueType  # 0
        MONDAY: TitleDetailView._UpdateTiming.ValueType  # 1
        TUESDAY: TitleDetailView._UpdateTiming.ValueType  # 2
        WEDNESDAY: TitleDetailView._UpdateTiming.ValueType  # 3
        THURSDAY: TitleDetailView._UpdateTiming.ValueType  # 4
        FRIDAY: TitleDetailView._UpdateTiming.ValueType  # 5
        SATURDAY: TitleDetailView._UpdateTiming.ValueType  # 6
        SUNDAY: TitleDetailView._UpdateTiming.ValueType  # 7
        DAY: TitleDetailView._UpdateTiming.ValueType  # 8

    class UpdateTiming(_UpdateTiming, metaclass=_UpdateTimingEnumTypeWrapper): ...
    NOT_REGULARLY: TitleDetailView.UpdateTiming.ValueType  # 0
    MONDAY: TitleDetailView.UpdateTiming.ValueType  # 1
    TUESDAY: TitleDetailView.UpdateTiming.ValueType  # 2
    WEDNESDAY: TitleDetailView.UpdateTiming.ValueType  # 3
    THURSDAY: TitleDetailView.UpdateTiming.ValueType  # 4
    FRIDAY: TitleDetailView.UpdateTiming.ValueType  # 5
    SATURDAY: TitleDetailView.UpdateTiming.ValueType  # 6
    SUNDAY: TitleDetailView.UpdateTiming.ValueType  # 7
    DAY: TitleDetailView.UpdateTiming.ValueType  # 8

    class _Rating:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RatingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TitleDetailView._Rating.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ALLAGE: TitleDetailView._Rating.ValueType  # 0
        TEEN: TitleDetailView._Rating.ValueType  # 1
        TEENPLUS: TitleDetailView._Rating.ValueType  # 2
        MATURE: TitleDetailView._Rating.ValueType  # 3

    class Rating(_Rating, metaclass=_RatingEnumTypeWrapper): ...
    ALLAGE: TitleDetailView.Rating.ValueType  # 0
    TEEN: TitleDetailView.Rating.ValueType  # 1
    TEENPLUS: TitleDetailView.Rating.ValueType  # 2
    MATURE: TitleDetailView.Rating.ValueType  # 3

    @typing.final
    class TitleLabels(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        RELEASESCHEDULE_FIELD_NUMBER: builtins.int
        ISSIMULPUB_FIELD_NUMBER: builtins.int
        PLANTYPE_FIELD_NUMBER: builtins.int
        releaseSchedule: builtins.int
        isSimulpub: builtins.bool
        planType: builtins.str
        def __init__(
            self,
            *,
            releaseSchedule: builtins.int = ...,
            isSimulpub: builtins.bool = ...,
            planType: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["isSimulpub", b"isSimulpub", "planType", b"planType", "releaseSchedule", b"releaseSchedule"]) -> None: ...

    @typing.final
    class PublisherItem(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BANNER_FIELD_NUMBER: builtins.int
        PUBLISHERNEWS_FIELD_NUMBER: builtins.int
        @property
        def banner(self) -> global___Banner: ...
        @property
        def publisherNews(self) -> global___PublisherNews: ...
        def __init__(
            self,
            *,
            banner: global___Banner | None = ...,
            publisherNews: global___PublisherNews | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["banner", b"banner", "publisherNews", b"publisherNews"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["banner", b"banner", "publisherNews", b"publisherNews"]) -> None: ...

    @typing.final
    class TitleLanguages(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TITLEID_FIELD_NUMBER: builtins.int
        LANGUAGE_FIELD_NUMBER: builtins.int
        titleId: builtins.int
        language: global___Language.ValueType
        def __init__(
            self,
            *,
            titleId: builtins.int = ...,
            language: global___Language.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["language", b"language", "titleId", b"titleId"]) -> None: ...

    @typing.final
    class ChapterGroup(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CHAPTERNUMBERS_FIELD_NUMBER: builtins.int
        FIRSTCHAPTERLIST_FIELD_NUMBER: builtins.int
        MIDCHAPTERLIST_FIELD_NUMBER: builtins.int
        LASTCHAPTERLIST_FIELD_NUMBER: builtins.int
        chapterNumbers: builtins.str
        @property
        def firstChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
        @property
        def midChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
        @property
        def lastChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
        def __init__(
            self,
            *,
            chapterNumbers: builtins.str = ...,
            firstChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
            midChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
            lastChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["chapterNumbers", b"chapterNumbers", "firstChapterList", b"firstChapterList", "lastChapterList", b"lastChapterList", "midChapterList", b"midChapterList"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    TITLEIMAGEURL_FIELD_NUMBER: builtins.int
    OVERVIEW_FIELD_NUMBER: builtins.int
    BACKGROUNDIMAGEURL_FIELD_NUMBER: builtins.int
    NEXTTIMESTAMP_FIELD_NUMBER: builtins.int
    UPDATETIMING_FIELD_NUMBER: builtins.int
    VIEWINGPERIODDESCRIPTION_FIELD_NUMBER: builtins.int
    NONAPPEARANCEINFO_FIELD_NUMBER: builtins.int
    FIRSTCHAPTERLIST_FIELD_NUMBER: builtins.int
    LASTCHAPTERLIST_FIELD_NUMBER: builtins.int
    BANNERS_FIELD_NUMBER: builtins.int
    RECOMMENDEDTITLELIST_FIELD_NUMBER: builtins.int
    SNS_FIELD_NUMBER: builtins.int
    ISSIMULRELEASED_FIELD_NUMBER: builtins.int
    ISSUBSCRIBED_FIELD_NUMBER: builtins.int
    RATING_FIELD_NUMBER: builtins.int
    CHAPTERSDESCENDING_FIELD_NUMBER: builtins.int
    NUMBEROFVIEWS_FIELD_NUMBER: builtins.int
    PUBLISHERITEMS_FIELD_NUMBER: builtins.int
    TITLEBANNERS_FIELD_NUMBER: builtins.int
    USERTICKETS_FIELD_NUMBER: builtins.int
    TICKETCHAPTERLIST_FIELD_NUMBER: builtins.int
    TICKETTITLELIST_FIELD_NUMBER: builtins.int
    HASCHAPTERSBETWEEN_FIELD_NUMBER: builtins.int
    PUBLISHERBANNER_FIELD_NUMBER: builtins.int
    ADVERTISEMENT_FIELD_NUMBER: builtins.int
    TITLELANGUAGES_FIELD_NUMBER: builtins.int
    CHAPTERLISTGROUP_FIELD_NUMBER: builtins.int
    FREEVIEWDIALOGUE_FIELD_NUMBER: builtins.int
    REGIONCODE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TITLELABELS_FIELD_NUMBER: builtins.int
    USERSUBSCRIPTION_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    ISFIRSTTIMEFREE_FIELD_NUMBER: builtins.int
    METAINFO_FIELD_NUMBER: builtins.int
    RATINGPOPUP_FIELD_NUMBER: builtins.int
    titleImageUrl: builtins.str
    overview: builtins.str
    backgroundImageUrl: builtins.str
    nextTimeStamp: builtins.int
    updateTiming: builtins.int
    viewingPeriodDescription: builtins.str
    nonAppearanceInfo: builtins.str
    isSimulReleased: builtins.bool
    isSubscribed: builtins.bool
    rating: global___TitleDetailView.Rating.ValueType
    chaptersDescending: builtins.bool
    numberOfViews: builtins.int
    hasChaptersBetween: builtins.bool
    regionCode: builtins.str
    isFirstTimeFree: builtins.bool
    @property
    def title(self) -> global___Title: ...
    @property
    def firstChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
    @property
    def lastChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
    @property
    def banners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def recommendedTitleList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    @property
    def sns(self) -> global___Sns: ...
    @property
    def publisherItems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleDetailView.PublisherItem]: ...
    @property
    def titleBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def userTickets(self) -> global___UserTickets: ...
    @property
    def ticketChapterList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chapter]: ...
    @property
    def ticketTitleList(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    @property
    def publisherBanner(self) -> global___Banner: ...
    @property
    def advertisement(self) -> global___AdNetworkList: ...
    @property
    def titleLanguages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleDetailView.TitleLanguages]: ...
    @property
    def chapterListGroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleDetailView.ChapterGroup]: ...
    @property
    def freeViewDialogue(self) -> global___FreeViewDialogue: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]: ...
    @property
    def titleLabels(self) -> global___TitleDetailView.TitleLabels: ...
    @property
    def userSubscription(self) -> global___Subscription: ...
    @property
    def label(self) -> global___Label: ...
    @property
    def metaInfo(self) -> global___MetaInfo: ...
    @property
    def ratingPopup(self) -> global___Popup: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        titleImageUrl: builtins.str = ...,
        overview: builtins.str = ...,
        backgroundImageUrl: builtins.str = ...,
        nextTimeStamp: builtins.int = ...,
        updateTiming: builtins.int = ...,
        viewingPeriodDescription: builtins.str = ...,
        nonAppearanceInfo: builtins.str = ...,
        firstChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
        lastChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
        banners: collections.abc.Iterable[global___Banner] | None = ...,
        recommendedTitleList: collections.abc.Iterable[global___Title] | None = ...,
        sns: global___Sns | None = ...,
        isSimulReleased: builtins.bool = ...,
        isSubscribed: builtins.bool = ...,
        rating: global___TitleDetailView.Rating.ValueType = ...,
        chaptersDescending: builtins.bool = ...,
        numberOfViews: builtins.int = ...,
        publisherItems: collections.abc.Iterable[global___TitleDetailView.PublisherItem] | None = ...,
        titleBanners: collections.abc.Iterable[global___Banner] | None = ...,
        userTickets: global___UserTickets | None = ...,
        ticketChapterList: collections.abc.Iterable[global___Chapter] | None = ...,
        ticketTitleList: collections.abc.Iterable[global___Title] | None = ...,
        hasChaptersBetween: builtins.bool = ...,
        publisherBanner: global___Banner | None = ...,
        advertisement: global___AdNetworkList | None = ...,
        titleLanguages: collections.abc.Iterable[global___TitleDetailView.TitleLanguages] | None = ...,
        chapterListGroup: collections.abc.Iterable[global___TitleDetailView.ChapterGroup] | None = ...,
        freeViewDialogue: global___FreeViewDialogue | None = ...,
        regionCode: builtins.str = ...,
        tags: collections.abc.Iterable[global___Tag] | None = ...,
        titleLabels: global___TitleDetailView.TitleLabels | None = ...,
        userSubscription: global___Subscription | None = ...,
        label: global___Label | None = ...,
        isFirstTimeFree: builtins.bool = ...,
        metaInfo: global___MetaInfo | None = ...,
        ratingPopup: global___Popup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["advertisement", b"advertisement", "freeViewDialogue", b"freeViewDialogue", "label", b"label", "metaInfo", b"metaInfo", "publisherBanner", b"publisherBanner", "ratingPopup", b"ratingPopup", "sns", b"sns", "title", b"title", "titleLabels", b"titleLabels", "userSubscription", b"userSubscription", "userTickets", b"userTickets"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["advertisement", b"advertisement", "backgroundImageUrl", b"backgroundImageUrl", "banners", b"banners", "chapterListGroup", b"chapterListGroup", "chaptersDescending", b"chaptersDescending", "firstChapterList", b"firstChapterList", "freeViewDialogue", b"freeViewDialogue", "hasChaptersBetween", b"hasChaptersBetween", "isFirstTimeFree", b"isFirstTimeFree", "isSimulReleased", b"isSimulReleased", "isSubscribed", b"isSubscribed", "label", b"label", "lastChapterList", b"lastChapterList", "metaInfo", b"metaInfo", "nextTimeStamp", b"nextTimeStamp", "nonAppearanceInfo", b"nonAppearanceInfo", "numberOfViews", b"numberOfViews", "overview", b"overview", "publisherBanner", b"publisherBanner", "publisherItems", b"publisherItems", "rating", b"rating", "ratingPopup", b"ratingPopup", "recommendedTitleList", b"recommendedTitleList", "regionCode", b"regionCode", "sns", b"sns", "tags", b"tags", "ticketChapterList", b"ticketChapterList", "ticketTitleList", b"ticketTitleList", "title", b"title", "titleBanners", b"titleBanners", "titleImageUrl", b"titleImageUrl", "titleLabels", b"titleLabels", "titleLanguages", b"titleLanguages", "updateTiming", b"updateTiming", "userSubscription", b"userSubscription", "userTickets", b"userTickets", "viewingPeriodDescription", b"viewingPeriodDescription"]) -> None: ...

global___TitleDetailView = TitleDetailView

@typing.final
class AllTitlesGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THETITLE_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    NEXTCHAPTERSTARTTIMESTAMP_FIELD_NUMBER: builtins.int
    theTitle: builtins.str
    nextChapterStartTimestamp: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Tag]: ...
    @property
    def label(self) -> global___Label: ...
    def __init__(
        self,
        *,
        theTitle: builtins.str = ...,
        titles: collections.abc.Iterable[global___Title] | None = ...,
        tags: collections.abc.Iterable[global___Tag] | None = ...,
        label: global___Label | None = ...,
        nextChapterStartTimestamp: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["label", b"label", "nextChapterStartTimestamp", b"nextChapterStartTimestamp", "tags", b"tags", "theTitle", b"theTitle", "titles", b"titles"]) -> None: ...

global___AllTitlesGroup = AllTitlesGroup

@typing.final
class TitleRankingGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORIGINALTITLEID_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    originalTitleId: builtins.int
    score: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        originalTitleId: builtins.int = ...,
        titles: collections.abc.Iterable[global___Title] | None = ...,
        score: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["originalTitleId", b"originalTitleId", "score", b"score", "titles", b"titles"]) -> None: ...

global___TitleRankingGroup = TitleRankingGroup

@typing.final
class TitleUpdatedGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATEDTITLETIMESTAMP_FIELD_NUMBER: builtins.int
    LATESTTITLE_FIELD_NUMBER: builtins.int
    updatedTitleTimestamp: builtins.int
    @property
    def latestTitle(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AllTitlesGroup]: ...
    def __init__(
        self,
        *,
        updatedTitleTimestamp: builtins.int = ...,
        latestTitle: collections.abc.Iterable[global___AllTitlesGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["latestTitle", b"latestTitle", "updatedTitleTimestamp", b"updatedTitleTimestamp"]) -> None: ...

global___TitleUpdatedGroup = TitleUpdatedGroup

@typing.final
class LabeledTitlesGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THETITLE_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    theTitle: builtins.str
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        theTitle: builtins.str = ...,
        titles: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["theTitle", b"theTitle", "titles", b"titles"]) -> None: ...

global___LabeledTitlesGroup = LabeledTitlesGroup

@typing.final
class TitleSubscriptionGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAN_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    TITLECOUNTTEXT_FIELD_NUMBER: builtins.int
    plan: builtins.str
    titleCountText: builtins.str
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        plan: builtins.str = ...,
        titles: collections.abc.Iterable[global___Title] | None = ...,
        titleCountText: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["plan", b"plan", "titleCountText", b"titleCountText", "titles", b"titles"]) -> None: ...

global___TitleSubscriptionGroup = TitleSubscriptionGroup

@typing.final
class TitleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LISTNAME_FIELD_NUMBER: builtins.int
    FEATUREDTITLES_FIELD_NUMBER: builtins.int
    CONTAINERID_FIELD_NUMBER: builtins.int
    listName: builtins.str
    containerId: builtins.int
    @property
    def featuredTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        listName: builtins.str = ...,
        featuredTitles: collections.abc.Iterable[global___Title] | None = ...,
        containerId: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["containerId", b"containerId", "featuredTitles", b"featuredTitles", "listName", b"listName"]) -> None: ...

global___TitleList = TitleList

@typing.final
class ChapterPageList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LISTNAME_FIELD_NUMBER: builtins.int
    CHAPTERPAGES_FIELD_NUMBER: builtins.int
    listName: builtins.str
    @property
    def chapterPages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChapterPages]: ...
    def __init__(
        self,
        *,
        listName: builtins.str = ...,
        chapterPages: collections.abc.Iterable[global___ChapterPages] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chapterPages", b"chapterPages", "listName", b"listName"]) -> None: ...

global___ChapterPageList = ChapterPageList

@typing.final
class ChapterPages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINERID_FIELD_NUMBER: builtins.int
    CHAPTERID_FIELD_NUMBER: builtins.int
    TITLEID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    FAVORITEIMAGEURL_FIELD_NUMBER: builtins.int
    PAGES_FIELD_NUMBER: builtins.int
    containerId: builtins.int
    chapterId: builtins.int
    titleId: builtins.int
    name: builtins.str
    author: builtins.str
    favoriteImageUrl: builtins.str
    @property
    def pages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Page]: ...
    def __init__(
        self,
        *,
        containerId: builtins.int = ...,
        chapterId: builtins.int = ...,
        titleId: builtins.int = ...,
        name: builtins.str = ...,
        author: builtins.str = ...,
        favoriteImageUrl: builtins.str = ...,
        pages: collections.abc.Iterable[global___Page] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "chapterId", b"chapterId", "containerId", b"containerId", "favoriteImageUrl", b"favoriteImageUrl", "name", b"name", "pages", b"pages", "titleId", b"titleId"]) -> None: ...

global___ChapterPages = ChapterPages

@typing.final
class Title(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLEID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    PORTRAITIMAGEURL_FIELD_NUMBER: builtins.int
    LANDSCAPEIMAGEURL_FIELD_NUMBER: builtins.int
    VIEWCOUNT_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    TITLEUPDATESTATUS_FIELD_NUMBER: builtins.int
    FAVORITEIMAGEURL_FIELD_NUMBER: builtins.int
    titleId: builtins.int
    name: builtins.str
    author: builtins.str
    portraitImageUrl: builtins.str
    landscapeImageUrl: builtins.str
    viewCount: builtins.int
    language: global___Language.ValueType
    titleUpdateStatus: global___TitleUpdateStatus.ValueType
    favoriteImageUrl: builtins.str
    def __init__(
        self,
        *,
        titleId: builtins.int = ...,
        name: builtins.str = ...,
        author: builtins.str = ...,
        portraitImageUrl: builtins.str = ...,
        landscapeImageUrl: builtins.str = ...,
        viewCount: builtins.int = ...,
        language: global___Language.ValueType = ...,
        titleUpdateStatus: global___TitleUpdateStatus.ValueType = ...,
        favoriteImageUrl: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["author", b"author", "favoriteImageUrl", b"favoriteImageUrl", "landscapeImageUrl", b"landscapeImageUrl", "language", b"language", "name", b"name", "portraitImageUrl", b"portraitImageUrl", "titleId", b"titleId", "titleUpdateStatus", b"titleUpdateStatus", "viewCount", b"viewCount"]) -> None: ...

global___Title = Title

@typing.final
class UpdatedTitle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CHAPTERID_FIELD_NUMBER: builtins.int
    CHAPTERNAME_FIELD_NUMBER: builtins.int
    CHAPTERSUBTITLE_FIELD_NUMBER: builtins.int
    ISLATEST_FIELD_NUMBER: builtins.int
    ISVERTICALONLY_FIELD_NUMBER: builtins.int
    ISHORIZONTALONLY_FIELD_NUMBER: builtins.int
    chapterId: builtins.int
    chapterName: builtins.str
    chapterSubTitle: builtins.str
    isLatest: builtins.bool
    isVerticalOnly: builtins.bool
    isHorizontalOnly: builtins.bool
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        chapterId: builtins.int = ...,
        chapterName: builtins.str = ...,
        chapterSubTitle: builtins.str = ...,
        isLatest: builtins.bool = ...,
        isVerticalOnly: builtins.bool = ...,
        isHorizontalOnly: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chapterId", b"chapterId", "chapterName", b"chapterName", "chapterSubTitle", b"chapterSubTitle", "isHorizontalOnly", b"isHorizontalOnly", "isLatest", b"isLatest", "isVerticalOnly", b"isVerticalOnly", "title", b"title"]) -> None: ...

global___UpdatedTitle = UpdatedTitle

@typing.final
class TitleUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    UPDATEDTITLETIMESTAMP_FIELD_NUMBER: builtins.int
    updatedTitleTimestamp: builtins.str
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        updatedTitleTimestamp: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["title", b"title", "updatedTitleTimestamp", b"updatedTitleTimestamp"]) -> None: ...

global___TitleUpdated = TitleUpdated

@typing.final
class FreeTitle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    UPDATEDTITLETIMESTAMP_FIELD_NUMBER: builtins.int
    updatedTitleTimestamp: builtins.str
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        updatedTitleTimestamp: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["title", b"title", "updatedTitleTimestamp", b"updatedTitleTimestamp"]) -> None: ...

global___FreeTitle = FreeTitle

@typing.final
class TicketTitles(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    FIRSTTICKETCHAPTER_FIELD_NUMBER: builtins.int
    LASTTICKETCHAPTER_FIELD_NUMBER: builtins.int
    firstTicketChapter: builtins.int
    lastTicketChapter: builtins.int
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        firstTicketChapter: builtins.int = ...,
        lastTicketChapter: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["firstTicketChapter", b"firstTicketChapter", "lastTicketChapter", b"lastTicketChapter", "title", b"title"]) -> None: ...

global___TicketTitles = TicketTitles

@typing.final
class SubscribableTitle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ISLATEST_FIELD_NUMBER: builtins.int
    ISSUBSCRIBED_FIELD_NUMBER: builtins.int
    isLatest: builtins.bool
    isSubscribed: builtins.bool
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        isLatest: builtins.bool = ...,
        isSubscribed: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["isLatest", b"isLatest", "isSubscribed", b"isSubscribed", "title", b"title"]) -> None: ...

global___SubscribableTitle = SubscribableTitle

@typing.final
class ComingSoonTitle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    NEXTCHAPTERNAME_FIELD_NUMBER: builtins.int
    NEXTCHAPTERSTARTTIMESTAMP_FIELD_NUMBER: builtins.int
    nextChapterName: builtins.str
    nextChapterStartTimestamp: builtins.int
    @property
    def title(self) -> global___Title: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        nextChapterName: builtins.str = ...,
        nextChapterStartTimestamp: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["nextChapterName", b"nextChapterName", "nextChapterStartTimestamp", b"nextChapterStartTimestamp", "title", b"title"]) -> None: ...

global___ComingSoonTitle = ComingSoonTitle

@typing.final
class TitleHighlight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CHAPTERID_FIELD_NUMBER: builtins.int
    PAGEURLLIST_FIELD_NUMBER: builtins.int
    PAGEHIGHT_FIELD_NUMBER: builtins.int
    PAGEWIDTH_FIELD_NUMBER: builtins.int
    ISVERTICALONLY_FIELD_NUMBER: builtins.int
    ISHORIZONTALONLY_FIELD_NUMBER: builtins.int
    chapterId: builtins.int
    pageHight: builtins.int
    pageWidth: builtins.int
    isVerticalOnly: builtins.bool
    isHorizontalOnly: builtins.bool
    @property
    def title(self) -> global___Title: ...
    @property
    def pageUrlList(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        title: global___Title | None = ...,
        chapterId: builtins.int = ...,
        pageUrlList: collections.abc.Iterable[builtins.str] | None = ...,
        pageHight: builtins.int = ...,
        pageWidth: builtins.int = ...,
        isVerticalOnly: builtins.bool = ...,
        isHorizontalOnly: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["chapterId", b"chapterId", "isHorizontalOnly", b"isHorizontalOnly", "isVerticalOnly", b"isVerticalOnly", "pageHight", b"pageHight", "pageUrlList", b"pageUrlList", "pageWidth", b"pageWidth", "title", b"title"]) -> None: ...

global___TitleHighlight = TitleHighlight

@typing.final
class TitleRankingView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLES_FIELD_NUMBER: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Title]: ...
    def __init__(
        self,
        *,
        titles: collections.abc.Iterable[global___Title] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["titles", b"titles"]) -> None: ...

global___TitleRankingView = TitleRankingView

@typing.final
class TitleRankingViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RANKINGBANNERS_FIELD_NUMBER: builtins.int
    UPDATEDTIMESTAMP_FIELD_NUMBER: builtins.int
    RANKEDTITLES_FIELD_NUMBER: builtins.int
    updatedTimeStamp: builtins.int
    @property
    def rankingBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def rankedTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
    def __init__(
        self,
        *,
        rankingBanners: collections.abc.Iterable[global___Banner] | None = ...,
        updatedTimeStamp: builtins.int = ...,
        rankedTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rankedTitles", b"rankedTitles", "rankingBanners", b"rankingBanners", "updatedTimeStamp", b"updatedTimeStamp"]) -> None: ...

global___TitleRankingViewV2 = TitleRankingViewV2

@typing.final
class TitleUpdatedView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LATESTTITLE_FIELD_NUMBER: builtins.int
    @property
    def latestTitle(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleUpdated]: ...
    def __init__(
        self,
        *,
        latestTitle: collections.abc.Iterable[global___TitleUpdated] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["latestTitle", b"latestTitle"]) -> None: ...

global___TitleUpdatedView = TitleUpdatedView

@typing.final
class TitleUpdatedViewV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLEUPDATEDGROUP_FIELD_NUMBER: builtins.int
    @property
    def titleUpdatedGroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleUpdatedGroup]: ...
    def __init__(
        self,
        *,
        titleUpdatedGroup: collections.abc.Iterable[global___TitleUpdatedGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["titleUpdatedGroup", b"titleUpdatedGroup"]) -> None: ...

global___TitleUpdatedViewV2 = TitleUpdatedViewV2

@typing.final
class TransitionAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PresentationMethod:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PresentationMethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TransitionAction._PresentationMethod.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        PUSH: TransitionAction._PresentationMethod.ValueType  # 0
        MODAL: TransitionAction._PresentationMethod.ValueType  # 1
        EXTERNAL: TransitionAction._PresentationMethod.ValueType  # 2

    class PresentationMethod(_PresentationMethod, metaclass=_PresentationMethodEnumTypeWrapper): ...
    PUSH: TransitionAction.PresentationMethod.ValueType  # 0
    MODAL: TransitionAction.PresentationMethod.ValueType  # 1
    EXTERNAL: TransitionAction.PresentationMethod.ValueType  # 2

    METHOD_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    method: global___TransitionAction.PresentationMethod.ValueType
    url: builtins.str
    def __init__(
        self,
        *,
        method: global___TransitionAction.PresentationMethod.ValueType = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["method", b"method", "url", b"url"]) -> None: ...

global___TransitionAction = TransitionAction

@typing.final
class UpdatedTitleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPNAME_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    groupName: builtins.str
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdatedTitle]: ...
    def __init__(
        self,
        *,
        groupName: builtins.str = ...,
        titles: collections.abc.Iterable[global___UpdatedTitle] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groupName", b"groupName", "titles", b"titles"]) -> None: ...

global___UpdatedTitleGroup = UpdatedTitleGroup

@typing.final
class UpdatedTitleV2Group(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPNAME_FIELD_NUMBER: builtins.int
    TITLEGROUPS_FIELD_NUMBER: builtins.int
    GROUPNAMEDAYS_FIELD_NUMBER: builtins.int
    groupName: builtins.str
    groupNameDays: builtins.int
    @property
    def titleGroups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OriginalTitleGroup]: ...
    def __init__(
        self,
        *,
        groupName: builtins.str = ...,
        titleGroups: collections.abc.Iterable[global___OriginalTitleGroup] | None = ...,
        groupNameDays: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groupName", b"groupName", "groupNameDays", b"groupNameDays", "titleGroups", b"titleGroups"]) -> None: ...

global___UpdatedTitleV2Group = UpdatedTitleV2Group

@typing.final
class OriginalTitleGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THETITLE_FIELD_NUMBER: builtins.int
    CHAPTERNUMBER_FIELD_NUMBER: builtins.int
    TITLES_FIELD_NUMBER: builtins.int
    VIEWCOUNT_FIELD_NUMBER: builtins.int
    TITLEUPDATESTATUS_FIELD_NUMBER: builtins.int
    CHAPTERSTARTTIME_FIELD_NUMBER: builtins.int
    theTitle: builtins.str
    chapterNumber: builtins.str
    viewCount: builtins.int
    titleUpdateStatus: global___TitleUpdateStatus.ValueType
    chapterStartTime: builtins.int
    @property
    def titles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdatedTitle]: ...
    def __init__(
        self,
        *,
        theTitle: builtins.str = ...,
        chapterNumber: builtins.str = ...,
        titles: collections.abc.Iterable[global___UpdatedTitle] | None = ...,
        viewCount: builtins.int = ...,
        titleUpdateStatus: global___TitleUpdateStatus.ValueType = ...,
        chapterStartTime: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chapterNumber", b"chapterNumber", "chapterStartTime", b"chapterStartTime", "theTitle", b"theTitle", "titleUpdateStatus", b"titleUpdateStatus", "titles", b"titles", "viewCount", b"viewCount"]) -> None: ...

global___OriginalTitleGroup = OriginalTitleGroup

@typing.final
class UpdatedTitleListView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdatedTitleGroup]: ...
    def __init__(
        self,
        *,
        groups: collections.abc.Iterable[global___UpdatedTitleGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["groups", b"groups"]) -> None: ...

global___UpdatedTitleListView = UpdatedTitleListView

@typing.final
class UpdateProfileResultView(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Result:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateProfileResultView._Result.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SUCCESS: UpdateProfileResultView._Result.ValueType  # 0
        DUPLICATED: UpdateProfileResultView._Result.ValueType  # 1
        NG_WORD: UpdateProfileResultView._Result.ValueType  # 2

    class Result(_Result, metaclass=_ResultEnumTypeWrapper): ...
    SUCCESS: UpdateProfileResultView.Result.ValueType  # 0
    DUPLICATED: UpdateProfileResultView.Result.ValueType  # 1
    NG_WORD: UpdateProfileResultView.Result.ValueType  # 2

    RESULT_FIELD_NUMBER: builtins.int
    result: global___UpdateProfileResultView.Result.ValueType
    def __init__(
        self,
        *,
        result: global___UpdateProfileResultView.Result.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["result", b"result"]) -> None: ...

global___UpdateProfileResultView = UpdateProfileResultView

@typing.final
class UserTickets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENTTICKETS_FIELD_NUMBER: builtins.int
    NEXTTICKETTIMESTAMP_FIELD_NUMBER: builtins.int
    currentTickets: builtins.int
    nextTicketTimestamp: builtins.int
    def __init__(
        self,
        *,
        currentTickets: builtins.int = ...,
        nextTicketTimestamp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["currentTickets", b"currentTickets", "nextTicketTimestamp", b"nextTicketTimestamp"]) -> None: ...

global___UserTickets = UserTickets

@typing.final
class WebHomeViewV4(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPBANNERS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    RANKEDTITLES_FIELD_NUMBER: builtins.int
    POPUP_FIELD_NUMBER: builtins.int
    FEATUREDTITLELISTS_FIELD_NUMBER: builtins.int
    SERVICEANNOUNCEMENTS_FIELD_NUMBER: builtins.int
    @property
    def topBanners(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Banner]: ...
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UpdatedTitleV2Group]: ...
    @property
    def rankedTitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleRankingGroup]: ...
    @property
    def popup(self) -> global___Popup: ...
    @property
    def featuredTitleLists(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TitleList]: ...
    @property
    def serviceAnnouncements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAnnouncement]: ...
    def __init__(
        self,
        *,
        topBanners: collections.abc.Iterable[global___Banner] | None = ...,
        groups: collections.abc.Iterable[global___UpdatedTitleV2Group] | None = ...,
        rankedTitles: collections.abc.Iterable[global___TitleRankingGroup] | None = ...,
        popup: global___Popup | None = ...,
        featuredTitleLists: collections.abc.Iterable[global___TitleList] | None = ...,
        serviceAnnouncements: collections.abc.Iterable[global___ServiceAnnouncement] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["popup", b"popup"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["featuredTitleLists", b"featuredTitleLists", "groups", b"groups", "popup", b"popup", "rankedTitles", b"rankedTitles", "serviceAnnouncements", b"serviceAnnouncements", "topBanners", b"topBanners"]) -> None: ...

global___WebHomeViewV4 = WebHomeViewV4
